#
# This file is part of KoreanCodecs.
#
# Copyright(C) Hye-Shik Chang <perky@FreeBSD.org>, 2002.
#
# KoreanCodecs is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# KoreanCodecs is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with KoreanCodecs; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# $Id: ksc5601_hangul.py,v 1.3 2002/07/19 00:01:52 perky Exp $
#

decoding_map = {
'\xb0\xa1': u'\uac00',
'\xb0\xa2': u'\uac01',
'\xb0\xa3': u'\uac04',
'\xb0\xa4': u'\uac07',
'\xb0\xa5': u'\uac08',
'\xb0\xa6': u'\uac09',
'\xb0\xa7': u'\uac0a',
'\xb0\xa8': u'\uac10',
'\xb0\xa9': u'\uac11',
'\xb0\xaa': u'\uac12',
'\xb0\xab': u'\uac13',
'\xb0\xac': u'\uac14',
'\xb0\xad': u'\uac15',
'\xb0\xae': u'\uac16',
'\xb0\xaf': u'\uac17',
'\xb0\xb0': u'\uac19',
'\xb0\xb1': u'\uac1a',
'\xb0\xb2': u'\uac1b',
'\xb0\xb3': u'\uac1c',
'\xb0\xb4': u'\uac1d',
'\xb0\xb5': u'\uac20',
'\xb0\xb6': u'\uac24',
'\xb0\xb7': u'\uac2c',
'\xb0\xb8': u'\uac2d',
'\xb0\xb9': u'\uac2f',
'\xb0\xba': u'\uac30',
'\xb0\xbb': u'\uac31',
'\xb0\xbc': u'\uac38',
'\xb0\xbd': u'\uac39',
'\xb0\xbe': u'\uac3c',
'\xb0\xbf': u'\uac40',
'\xb0\xc0': u'\uac4b',
'\xb0\xc1': u'\uac4d',
'\xb0\xc2': u'\uac54',
'\xb0\xc3': u'\uac58',
'\xb0\xc4': u'\uac5c',
'\xb0\xc5': u'\uac70',
'\xb0\xc6': u'\uac71',
'\xb0\xc7': u'\uac74',
'\xb0\xc8': u'\uac77',
'\xb0\xc9': u'\uac78',
'\xb0\xca': u'\uac7a',
'\xb0\xcb': u'\uac80',
'\xb0\xcc': u'\uac81',
'\xb0\xcd': u'\uac83',
'\xb0\xce': u'\uac84',
'\xb0\xcf': u'\uac85',
'\xb0\xd0': u'\uac86',
'\xb0\xd1': u'\uac89',
'\xb0\xd2': u'\uac8a',
'\xb0\xd3': u'\uac8b',
'\xb0\xd4': u'\uac8c',
'\xb0\xd5': u'\uac90',
'\xb0\xd6': u'\uac94',
'\xb0\xd7': u'\uac9c',
'\xb0\xd8': u'\uac9d',
'\xb0\xd9': u'\uac9f',
'\xb0\xda': u'\uaca0',
'\xb0\xdb': u'\uaca1',
'\xb0\xdc': u'\uaca8',
'\xb0\xdd': u'\uaca9',
'\xb0\xde': u'\uacaa',
'\xb0\xdf': u'\uacac',
'\xb0\xe0': u'\uacaf',
'\xb0\xe1': u'\uacb0',
'\xb0\xe2': u'\uacb8',
'\xb0\xe3': u'\uacb9',
'\xb0\xe4': u'\uacbb',
'\xb0\xe5': u'\uacbc',
'\xb0\xe6': u'\uacbd',
'\xb0\xe7': u'\uacc1',
'\xb0\xe8': u'\uacc4',
'\xb0\xe9': u'\uacc8',
'\xb0\xea': u'\uaccc',
'\xb0\xeb': u'\uacd5',
'\xb0\xec': u'\uacd7',
'\xb0\xed': u'\uace0',
'\xb0\xee': u'\uace1',
'\xb0\xef': u'\uace4',
'\xb0\xf0': u'\uace7',
'\xb0\xf1': u'\uace8',
'\xb0\xf2': u'\uacea',
'\xb0\xf3': u'\uacec',
'\xb0\xf4': u'\uacef',
'\xb0\xf5': u'\uacf0',
'\xb0\xf6': u'\uacf1',
'\xb0\xf7': u'\uacf3',
'\xb0\xf8': u'\uacf5',
'\xb0\xf9': u'\uacf6',
'\xb0\xfa': u'\uacfc',
'\xb0\xfb': u'\uacfd',
'\xb0\xfc': u'\uad00',
'\xb0\xfd': u'\uad04',
'\xb0\xfe': u'\uad06',
'\xb1\xa1': u'\uad0c',
'\xb1\xa2': u'\uad0d',
'\xb1\xa3': u'\uad0f',
'\xb1\xa4': u'\uad11',
'\xb1\xa5': u'\uad18',
'\xb1\xa6': u'\uad1c',
'\xb1\xa7': u'\uad20',
'\xb1\xa8': u'\uad29',
'\xb1\xa9': u'\uad2c',
'\xb1\xaa': u'\uad2d',
'\xb1\xab': u'\uad34',
'\xb1\xac': u'\uad35',
'\xb1\xad': u'\uad38',
'\xb1\xae': u'\uad3c',
'\xb1\xaf': u'\uad44',
'\xb1\xb0': u'\uad45',
'\xb1\xb1': u'\uad47',
'\xb1\xb2': u'\uad49',
'\xb1\xb3': u'\uad50',
'\xb1\xb4': u'\uad54',
'\xb1\xb5': u'\uad58',
'\xb1\xb6': u'\uad61',
'\xb1\xb7': u'\uad63',
'\xb1\xb8': u'\uad6c',
'\xb1\xb9': u'\uad6d',
'\xb1\xba': u'\uad70',
'\xb1\xbb': u'\uad73',
'\xb1\xbc': u'\uad74',
'\xb1\xbd': u'\uad75',
'\xb1\xbe': u'\uad76',
'\xb1\xbf': u'\uad7b',
'\xb1\xc0': u'\uad7c',
'\xb1\xc1': u'\uad7d',
'\xb1\xc2': u'\uad7f',
'\xb1\xc3': u'\uad81',
'\xb1\xc4': u'\uad82',
'\xb1\xc5': u'\uad88',
'\xb1\xc6': u'\uad89',
'\xb1\xc7': u'\uad8c',
'\xb1\xc8': u'\uad90',
'\xb1\xc9': u'\uad9c',
'\xb1\xca': u'\uad9d',
'\xb1\xcb': u'\uada4',
'\xb1\xcc': u'\uadb7',
'\xb1\xcd': u'\uadc0',
'\xb1\xce': u'\uadc1',
'\xb1\xcf': u'\uadc4',
'\xb1\xd0': u'\uadc8',
'\xb1\xd1': u'\uadd0',
'\xb1\xd2': u'\uadd1',
'\xb1\xd3': u'\uadd3',
'\xb1\xd4': u'\uaddc',
'\xb1\xd5': u'\uade0',
'\xb1\xd6': u'\uade4',
'\xb1\xd7': u'\uadf8',
'\xb1\xd8': u'\uadf9',
'\xb1\xd9': u'\uadfc',
'\xb1\xda': u'\uadff',
'\xb1\xdb': u'\uae00',
'\xb1\xdc': u'\uae01',
'\xb1\xdd': u'\uae08',
'\xb1\xde': u'\uae09',
'\xb1\xdf': u'\uae0b',
'\xb1\xe0': u'\uae0d',
'\xb1\xe1': u'\uae14',
'\xb1\xe2': u'\uae30',
'\xb1\xe3': u'\uae31',
'\xb1\xe4': u'\uae34',
'\xb1\xe5': u'\uae37',
'\xb1\xe6': u'\uae38',
'\xb1\xe7': u'\uae3a',
'\xb1\xe8': u'\uae40',
'\xb1\xe9': u'\uae41',
'\xb1\xea': u'\uae43',
'\xb1\xeb': u'\uae45',
'\xb1\xec': u'\uae46',
'\xb1\xed': u'\uae4a',
'\xb1\xee': u'\uae4c',
'\xb1\xef': u'\uae4d',
'\xb1\xf0': u'\uae4e',
'\xb1\xf1': u'\uae50',
'\xb1\xf2': u'\uae54',
'\xb1\xf3': u'\uae56',
'\xb1\xf4': u'\uae5c',
'\xb1\xf5': u'\uae5d',
'\xb1\xf6': u'\uae5f',
'\xb1\xf7': u'\uae60',
'\xb1\xf8': u'\uae61',
'\xb1\xf9': u'\uae65',
'\xb1\xfa': u'\uae68',
'\xb1\xfb': u'\uae69',
'\xb1\xfc': u'\uae6c',
'\xb1\xfd': u'\uae70',
'\xb1\xfe': u'\uae78',
'\xb2\xa1': u'\uae79',
'\xb2\xa2': u'\uae7b',
'\xb2\xa3': u'\uae7c',
'\xb2\xa4': u'\uae7d',
'\xb2\xa5': u'\uae84',
'\xb2\xa6': u'\uae85',
'\xb2\xa7': u'\uae8c',
'\xb2\xa8': u'\uaebc',
'\xb2\xa9': u'\uaebd',
'\xb2\xaa': u'\uaebe',
'\xb2\xab': u'\uaec0',
'\xb2\xac': u'\uaec4',
'\xb2\xad': u'\uaecc',
'\xb2\xae': u'\uaecd',
'\xb2\xaf': u'\uaecf',
'\xb2\xb0': u'\uaed0',
'\xb2\xb1': u'\uaed1',
'\xb2\xb2': u'\uaed8',
'\xb2\xb3': u'\uaed9',
'\xb2\xb4': u'\uaedc',
'\xb2\xb5': u'\uaee8',
'\xb2\xb6': u'\uaeeb',
'\xb2\xb7': u'\uaeed',
'\xb2\xb8': u'\uaef4',
'\xb2\xb9': u'\uaef8',
'\xb2\xba': u'\uaefc',
'\xb2\xbb': u'\uaf07',
'\xb2\xbc': u'\uaf08',
'\xb2\xbd': u'\uaf0d',
'\xb2\xbe': u'\uaf10',
'\xb2\xbf': u'\uaf2c',
'\xb2\xc0': u'\uaf2d',
'\xb2\xc1': u'\uaf30',
'\xb2\xc2': u'\uaf32',
'\xb2\xc3': u'\uaf34',
'\xb2\xc4': u'\uaf3c',
'\xb2\xc5': u'\uaf3d',
'\xb2\xc6': u'\uaf3f',
'\xb2\xc7': u'\uaf41',
'\xb2\xc8': u'\uaf42',
'\xb2\xc9': u'\uaf43',
'\xb2\xca': u'\uaf48',
'\xb2\xcb': u'\uaf49',
'\xb2\xcc': u'\uaf50',
'\xb2\xcd': u'\uaf5c',
'\xb2\xce': u'\uaf5d',
'\xb2\xcf': u'\uaf64',
'\xb2\xd0': u'\uaf65',
'\xb2\xd1': u'\uaf79',
'\xb2\xd2': u'\uaf80',
'\xb2\xd3': u'\uaf84',
'\xb2\xd4': u'\uaf88',
'\xb2\xd5': u'\uaf90',
'\xb2\xd6': u'\uaf91',
'\xb2\xd7': u'\uaf95',
'\xb2\xd8': u'\uaf9c',
'\xb2\xd9': u'\uafb8',
'\xb2\xda': u'\uafb9',
'\xb2\xdb': u'\uafbc',
'\xb2\xdc': u'\uafc0',
'\xb2\xdd': u'\uafc7',
'\xb2\xde': u'\uafc8',
'\xb2\xdf': u'\uafc9',
'\xb2\xe0': u'\uafcb',
'\xb2\xe1': u'\uafcd',
'\xb2\xe2': u'\uafce',
'\xb2\xe3': u'\uafd4',
'\xb2\xe4': u'\uafdc',
'\xb2\xe5': u'\uafe8',
'\xb2\xe6': u'\uafe9',
'\xb2\xe7': u'\uaff0',
'\xb2\xe8': u'\uaff1',
'\xb2\xe9': u'\uaff4',
'\xb2\xea': u'\uaff8',
'\xb2\xeb': u'\ub000',
'\xb2\xec': u'\ub001',
'\xb2\xed': u'\ub004',
'\xb2\xee': u'\ub00c',
'\xb2\xef': u'\ub010',
'\xb2\xf0': u'\ub014',
'\xb2\xf1': u'\ub01c',
'\xb2\xf2': u'\ub01d',
'\xb2\xf3': u'\ub028',
'\xb2\xf4': u'\ub044',
'\xb2\xf5': u'\ub045',
'\xb2\xf6': u'\ub048',
'\xb2\xf7': u'\ub04a',
'\xb2\xf8': u'\ub04c',
'\xb2\xf9': u'\ub04e',
'\xb2\xfa': u'\ub053',
'\xb2\xfb': u'\ub054',
'\xb2\xfc': u'\ub055',
'\xb2\xfd': u'\ub057',
'\xb2\xfe': u'\ub059',
'\xb3\xa1': u'\ub05d',
'\xb3\xa2': u'\ub07c',
'\xb3\xa3': u'\ub07d',
'\xb3\xa4': u'\ub080',
'\xb3\xa5': u'\ub084',
'\xb3\xa6': u'\ub08c',
'\xb3\xa7': u'\ub08d',
'\xb3\xa8': u'\ub08f',
'\xb3\xa9': u'\ub091',
'\xb3\xaa': u'\ub098',
'\xb3\xab': u'\ub099',
'\xb3\xac': u'\ub09a',
'\xb3\xad': u'\ub09c',
'\xb3\xae': u'\ub09f',
'\xb3\xaf': u'\ub0a0',
'\xb3\xb0': u'\ub0a1',
'\xb3\xb1': u'\ub0a2',
'\xb3\xb2': u'\ub0a8',
'\xb3\xb3': u'\ub0a9',
'\xb3\xb4': u'\ub0ab',
'\xb3\xb5': u'\ub0ac',
'\xb3\xb6': u'\ub0ad',
'\xb3\xb7': u'\ub0ae',
'\xb3\xb8': u'\ub0af',
'\xb3\xb9': u'\ub0b1',
'\xb3\xba': u'\ub0b3',
'\xb3\xbb': u'\ub0b4',
'\xb3\xbc': u'\ub0b5',
'\xb3\xbd': u'\ub0b8',
'\xb3\xbe': u'\ub0bc',
'\xb3\xbf': u'\ub0c4',
'\xb3\xc0': u'\ub0c5',
'\xb3\xc1': u'\ub0c7',
'\xb3\xc2': u'\ub0c8',
'\xb3\xc3': u'\ub0c9',
'\xb3\xc4': u'\ub0d0',
'\xb3\xc5': u'\ub0d1',
'\xb3\xc6': u'\ub0d4',
'\xb3\xc7': u'\ub0d8',
'\xb3\xc8': u'\ub0e0',
'\xb3\xc9': u'\ub0e5',
'\xb3\xca': u'\ub108',
'\xb3\xcb': u'\ub109',
'\xb3\xcc': u'\ub10b',
'\xb3\xcd': u'\ub10c',
'\xb3\xce': u'\ub110',
'\xb3\xcf': u'\ub112',
'\xb3\xd0': u'\ub113',
'\xb3\xd1': u'\ub118',
'\xb3\xd2': u'\ub119',
'\xb3\xd3': u'\ub11b',
'\xb3\xd4': u'\ub11c',
'\xb3\xd5': u'\ub11d',
'\xb3\xd6': u'\ub123',
'\xb3\xd7': u'\ub124',
'\xb3\xd8': u'\ub125',
'\xb3\xd9': u'\ub128',
'\xb3\xda': u'\ub12c',
'\xb3\xdb': u'\ub134',
'\xb3\xdc': u'\ub135',
'\xb3\xdd': u'\ub137',
'\xb3\xde': u'\ub138',
'\xb3\xdf': u'\ub139',
'\xb3\xe0': u'\ub140',
'\xb3\xe1': u'\ub141',
'\xb3\xe2': u'\ub144',
'\xb3\xe3': u'\ub148',
'\xb3\xe4': u'\ub150',
'\xb3\xe5': u'\ub151',
'\xb3\xe6': u'\ub154',
'\xb3\xe7': u'\ub155',
'\xb3\xe8': u'\ub158',
'\xb3\xe9': u'\ub15c',
'\xb3\xea': u'\ub160',
'\xb3\xeb': u'\ub178',
'\xb3\xec': u'\ub179',
'\xb3\xed': u'\ub17c',
'\xb3\xee': u'\ub180',
'\xb3\xef': u'\ub182',
'\xb3\xf0': u'\ub188',
'\xb3\xf1': u'\ub189',
'\xb3\xf2': u'\ub18b',
'\xb3\xf3': u'\ub18d',
'\xb3\xf4': u'\ub192',
'\xb3\xf5': u'\ub193',
'\xb3\xf6': u'\ub194',
'\xb3\xf7': u'\ub198',
'\xb3\xf8': u'\ub19c',
'\xb3\xf9': u'\ub1a8',
'\xb3\xfa': u'\ub1cc',
'\xb3\xfb': u'\ub1d0',
'\xb3\xfc': u'\ub1d4',
'\xb3\xfd': u'\ub1dc',
'\xb3\xfe': u'\ub1dd',
'\xb4\xa1': u'\ub1df',
'\xb4\xa2': u'\ub1e8',
'\xb4\xa3': u'\ub1e9',
'\xb4\xa4': u'\ub1ec',
'\xb4\xa5': u'\ub1f0',
'\xb4\xa6': u'\ub1f9',
'\xb4\xa7': u'\ub1fb',
'\xb4\xa8': u'\ub1fd',
'\xb4\xa9': u'\ub204',
'\xb4\xaa': u'\ub205',
'\xb4\xab': u'\ub208',
'\xb4\xac': u'\ub20b',
'\xb4\xad': u'\ub20c',
'\xb4\xae': u'\ub214',
'\xb4\xaf': u'\ub215',
'\xb4\xb0': u'\ub217',
'\xb4\xb1': u'\ub219',
'\xb4\xb2': u'\ub220',
'\xb4\xb3': u'\ub234',
'\xb4\xb4': u'\ub23c',
'\xb4\xb5': u'\ub258',
'\xb4\xb6': u'\ub25c',
'\xb4\xb7': u'\ub260',
'\xb4\xb8': u'\ub268',
'\xb4\xb9': u'\ub269',
'\xb4\xba': u'\ub274',
'\xb4\xbb': u'\ub275',
'\xb4\xbc': u'\ub27c',
'\xb4\xbd': u'\ub284',
'\xb4\xbe': u'\ub285',
'\xb4\xbf': u'\ub289',
'\xb4\xc0': u'\ub290',
'\xb4\xc1': u'\ub291',
'\xb4\xc2': u'\ub294',
'\xb4\xc3': u'\ub298',
'\xb4\xc4': u'\ub299',
'\xb4\xc5': u'\ub29a',
'\xb4\xc6': u'\ub2a0',
'\xb4\xc7': u'\ub2a1',
'\xb4\xc8': u'\ub2a3',
'\xb4\xc9': u'\ub2a5',
'\xb4\xca': u'\ub2a6',
'\xb4\xcb': u'\ub2aa',
'\xb4\xcc': u'\ub2ac',
'\xb4\xcd': u'\ub2b0',
'\xb4\xce': u'\ub2b4',
'\xb4\xcf': u'\ub2c8',
'\xb4\xd0': u'\ub2c9',
'\xb4\xd1': u'\ub2cc',
'\xb4\xd2': u'\ub2d0',
'\xb4\xd3': u'\ub2d2',
'\xb4\xd4': u'\ub2d8',
'\xb4\xd5': u'\ub2d9',
'\xb4\xd6': u'\ub2db',
'\xb4\xd7': u'\ub2dd',
'\xb4\xd8': u'\ub2e2',
'\xb4\xd9': u'\ub2e4',
'\xb4\xda': u'\ub2e5',
'\xb4\xdb': u'\ub2e6',
'\xb4\xdc': u'\ub2e8',
'\xb4\xdd': u'\ub2eb',
'\xb4\xde': u'\ub2ec',
'\xb4\xdf': u'\ub2ed',
'\xb4\xe0': u'\ub2ee',
'\xb4\xe1': u'\ub2ef',
'\xb4\xe2': u'\ub2f3',
'\xb4\xe3': u'\ub2f4',
'\xb4\xe4': u'\ub2f5',
'\xb4\xe5': u'\ub2f7',
'\xb4\xe6': u'\ub2f8',
'\xb4\xe7': u'\ub2f9',
'\xb4\xe8': u'\ub2fa',
'\xb4\xe9': u'\ub2fb',
'\xb4\xea': u'\ub2ff',
'\xb4\xeb': u'\ub300',
'\xb4\xec': u'\ub301',
'\xb4\xed': u'\ub304',
'\xb4\xee': u'\ub308',
'\xb4\xef': u'\ub310',
'\xb4\xf0': u'\ub311',
'\xb4\xf1': u'\ub313',
'\xb4\xf2': u'\ub314',
'\xb4\xf3': u'\ub315',
'\xb4\xf4': u'\ub31c',
'\xb4\xf5': u'\ub354',
'\xb4\xf6': u'\ub355',
'\xb4\xf7': u'\ub356',
'\xb4\xf8': u'\ub358',
'\xb4\xf9': u'\ub35b',
'\xb4\xfa': u'\ub35c',
'\xb4\xfb': u'\ub35e',
'\xb4\xfc': u'\ub35f',
'\xb4\xfd': u'\ub364',
'\xb4\xfe': u'\ub365',
'\xb5\xa1': u'\ub367',
'\xb5\xa2': u'\ub369',
'\xb5\xa3': u'\ub36b',
'\xb5\xa4': u'\ub36e',
'\xb5\xa5': u'\ub370',
'\xb5\xa6': u'\ub371',
'\xb5\xa7': u'\ub374',
'\xb5\xa8': u'\ub378',
'\xb5\xa9': u'\ub380',
'\xb5\xaa': u'\ub381',
'\xb5\xab': u'\ub383',
'\xb5\xac': u'\ub384',
'\xb5\xad': u'\ub385',
'\xb5\xae': u'\ub38c',
'\xb5\xaf': u'\ub390',
'\xb5\xb0': u'\ub394',
'\xb5\xb1': u'\ub3a0',
'\xb5\xb2': u'\ub3a1',
'\xb5\xb3': u'\ub3a8',
'\xb5\xb4': u'\ub3ac',
'\xb5\xb5': u'\ub3c4',
'\xb5\xb6': u'\ub3c5',
'\xb5\xb7': u'\ub3c8',
'\xb5\xb8': u'\ub3cb',
'\xb5\xb9': u'\ub3cc',
'\xb5\xba': u'\ub3ce',
'\xb5\xbb': u'\ub3d0',
'\xb5\xbc': u'\ub3d4',
'\xb5\xbd': u'\ub3d5',
'\xb5\xbe': u'\ub3d7',
'\xb5\xbf': u'\ub3d9',
'\xb5\xc0': u'\ub3db',
'\xb5\xc1': u'\ub3dd',
'\xb5\xc2': u'\ub3e0',
'\xb5\xc3': u'\ub3e4',
'\xb5\xc4': u'\ub3e8',
'\xb5\xc5': u'\ub3fc',
'\xb5\xc6': u'\ub410',
'\xb5\xc7': u'\ub418',
'\xb5\xc8': u'\ub41c',
'\xb5\xc9': u'\ub420',
'\xb5\xca': u'\ub428',
'\xb5\xcb': u'\ub429',
'\xb5\xcc': u'\ub42b',
'\xb5\xcd': u'\ub434',
'\xb5\xce': u'\ub450',
'\xb5\xcf': u'\ub451',
'\xb5\xd0': u'\ub454',
'\xb5\xd1': u'\ub458',
'\xb5\xd2': u'\ub460',
'\xb5\xd3': u'\ub461',
'\xb5\xd4': u'\ub463',
'\xb5\xd5': u'\ub465',
'\xb5\xd6': u'\ub46c',
'\xb5\xd7': u'\ub480',
'\xb5\xd8': u'\ub488',
'\xb5\xd9': u'\ub49d',
'\xb5\xda': u'\ub4a4',
'\xb5\xdb': u'\ub4a8',
'\xb5\xdc': u'\ub4ac',
'\xb5\xdd': u'\ub4b5',
'\xb5\xde': u'\ub4b7',
'\xb5\xdf': u'\ub4b9',
'\xb5\xe0': u'\ub4c0',
'\xb5\xe1': u'\ub4c4',
'\xb5\xe2': u'\ub4c8',
'\xb5\xe3': u'\ub4d0',
'\xb5\xe4': u'\ub4d5',
'\xb5\xe5': u'\ub4dc',
'\xb5\xe6': u'\ub4dd',
'\xb5\xe7': u'\ub4e0',
'\xb5\xe8': u'\ub4e3',
'\xb5\xe9': u'\ub4e4',
'\xb5\xea': u'\ub4e6',
'\xb5\xeb': u'\ub4ec',
'\xb5\xec': u'\ub4ed',
'\xb5\xed': u'\ub4ef',
'\xb5\xee': u'\ub4f1',
'\xb5\xef': u'\ub4f8',
'\xb5\xf0': u'\ub514',
'\xb5\xf1': u'\ub515',
'\xb5\xf2': u'\ub518',
'\xb5\xf3': u'\ub51b',
'\xb5\xf4': u'\ub51c',
'\xb5\xf5': u'\ub524',
'\xb5\xf6': u'\ub525',
'\xb5\xf7': u'\ub527',
'\xb5\xf8': u'\ub528',
'\xb5\xf9': u'\ub529',
'\xb5\xfa': u'\ub52a',
'\xb5\xfb': u'\ub530',
'\xb5\xfc': u'\ub531',
'\xb5\xfd': u'\ub534',
'\xb5\xfe': u'\ub538',
'\xb6\xa1': u'\ub540',
'\xb6\xa2': u'\ub541',
'\xb6\xa3': u'\ub543',
'\xb6\xa4': u'\ub544',
'\xb6\xa5': u'\ub545',
'\xb6\xa6': u'\ub54b',
'\xb6\xa7': u'\ub54c',
'\xb6\xa8': u'\ub54d',
'\xb6\xa9': u'\ub550',
'\xb6\xaa': u'\ub554',
'\xb6\xab': u'\ub55c',
'\xb6\xac': u'\ub55d',
'\xb6\xad': u'\ub55f',
'\xb6\xae': u'\ub560',
'\xb6\xaf': u'\ub561',
'\xb6\xb0': u'\ub5a0',
'\xb6\xb1': u'\ub5a1',
'\xb6\xb2': u'\ub5a4',
'\xb6\xb3': u'\ub5a8',
'\xb6\xb4': u'\ub5aa',
'\xb6\xb5': u'\ub5ab',
'\xb6\xb6': u'\ub5b0',
'\xb6\xb7': u'\ub5b1',
'\xb6\xb8': u'\ub5b3',
'\xb6\xb9': u'\ub5b4',
'\xb6\xba': u'\ub5b5',
'\xb6\xbb': u'\ub5bb',
'\xb6\xbc': u'\ub5bc',
'\xb6\xbd': u'\ub5bd',
'\xb6\xbe': u'\ub5c0',
'\xb6\xbf': u'\ub5c4',
'\xb6\xc0': u'\ub5cc',
'\xb6\xc1': u'\ub5cd',
'\xb6\xc2': u'\ub5cf',
'\xb6\xc3': u'\ub5d0',
'\xb6\xc4': u'\ub5d1',
'\xb6\xc5': u'\ub5d8',
'\xb6\xc6': u'\ub5ec',
'\xb6\xc7': u'\ub610',
'\xb6\xc8': u'\ub611',
'\xb6\xc9': u'\ub614',
'\xb6\xca': u'\ub618',
'\xb6\xcb': u'\ub625',
'\xb6\xcc': u'\ub62c',
'\xb6\xcd': u'\ub634',
'\xb6\xce': u'\ub648',
'\xb6\xcf': u'\ub664',
'\xb6\xd0': u'\ub668',
'\xb6\xd1': u'\ub69c',
'\xb6\xd2': u'\ub69d',
'\xb6\xd3': u'\ub6a0',
'\xb6\xd4': u'\ub6a4',
'\xb6\xd5': u'\ub6ab',
'\xb6\xd6': u'\ub6ac',
'\xb6\xd7': u'\ub6b1',
'\xb6\xd8': u'\ub6d4',
'\xb6\xd9': u'\ub6f0',
'\xb6\xda': u'\ub6f4',
'\xb6\xdb': u'\ub6f8',
'\xb6\xdc': u'\ub700',
'\xb6\xdd': u'\ub701',
'\xb6\xde': u'\ub705',
'\xb6\xdf': u'\ub728',
'\xb6\xe0': u'\ub729',
'\xb6\xe1': u'\ub72c',
'\xb6\xe2': u'\ub72f',
'\xb6\xe3': u'\ub730',
'\xb6\xe4': u'\ub738',
'\xb6\xe5': u'\ub739',
'\xb6\xe6': u'\ub73b',
'\xb6\xe7': u'\ub744',
'\xb6\xe8': u'\ub748',
'\xb6\xe9': u'\ub74c',
'\xb6\xea': u'\ub754',
'\xb6\xeb': u'\ub755',
'\xb6\xec': u'\ub760',
'\xb6\xed': u'\ub764',
'\xb6\xee': u'\ub768',
'\xb6\xef': u'\ub770',
'\xb6\xf0': u'\ub771',
'\xb6\xf1': u'\ub773',
'\xb6\xf2': u'\ub775',
'\xb6\xf3': u'\ub77c',
'\xb6\xf4': u'\ub77d',
'\xb6\xf5': u'\ub780',
'\xb6\xf6': u'\ub784',
'\xb6\xf7': u'\ub78c',
'\xb6\xf8': u'\ub78d',
'\xb6\xf9': u'\ub78f',
'\xb6\xfa': u'\ub790',
'\xb6\xfb': u'\ub791',
'\xb6\xfc': u'\ub792',
'\xb6\xfd': u'\ub796',
'\xb6\xfe': u'\ub797',
'\xb7\xa1': u'\ub798',
'\xb7\xa2': u'\ub799',
'\xb7\xa3': u'\ub79c',
'\xb7\xa4': u'\ub7a0',
'\xb7\xa5': u'\ub7a8',
'\xb7\xa6': u'\ub7a9',
'\xb7\xa7': u'\ub7ab',
'\xb7\xa8': u'\ub7ac',
'\xb7\xa9': u'\ub7ad',
'\xb7\xaa': u'\ub7b4',
'\xb7\xab': u'\ub7b5',
'\xb7\xac': u'\ub7b8',
'\xb7\xad': u'\ub7c7',
'\xb7\xae': u'\ub7c9',
'\xb7\xaf': u'\ub7ec',
'\xb7\xb0': u'\ub7ed',
'\xb7\xb1': u'\ub7f0',
'\xb7\xb2': u'\ub7f4',
'\xb7\xb3': u'\ub7fc',
'\xb7\xb4': u'\ub7fd',
'\xb7\xb5': u'\ub7ff',
'\xb7\xb6': u'\ub800',
'\xb7\xb7': u'\ub801',
'\xb7\xb8': u'\ub807',
'\xb7\xb9': u'\ub808',
'\xb7\xba': u'\ub809',
'\xb7\xbb': u'\ub80c',
'\xb7\xbc': u'\ub810',
'\xb7\xbd': u'\ub818',
'\xb7\xbe': u'\ub819',
'\xb7\xbf': u'\ub81b',
'\xb7\xc0': u'\ub81d',
'\xb7\xc1': u'\ub824',
'\xb7\xc2': u'\ub825',
'\xb7\xc3': u'\ub828',
'\xb7\xc4': u'\ub82c',
'\xb7\xc5': u'\ub834',
'\xb7\xc6': u'\ub835',
'\xb7\xc7': u'\ub837',
'\xb7\xc8': u'\ub838',
'\xb7\xc9': u'\ub839',
'\xb7\xca': u'\ub840',
'\xb7\xcb': u'\ub844',
'\xb7\xcc': u'\ub851',
'\xb7\xcd': u'\ub853',
'\xb7\xce': u'\ub85c',
'\xb7\xcf': u'\ub85d',
'\xb7\xd0': u'\ub860',
'\xb7\xd1': u'\ub864',
'\xb7\xd2': u'\ub86c',
'\xb7\xd3': u'\ub86d',
'\xb7\xd4': u'\ub86f',
'\xb7\xd5': u'\ub871',
'\xb7\xd6': u'\ub878',
'\xb7\xd7': u'\ub87c',
'\xb7\xd8': u'\ub88d',
'\xb7\xd9': u'\ub8a8',
'\xb7\xda': u'\ub8b0',
'\xb7\xdb': u'\ub8b4',
'\xb7\xdc': u'\ub8b8',
'\xb7\xdd': u'\ub8c0',
'\xb7\xde': u'\ub8c1',
'\xb7\xdf': u'\ub8c3',
'\xb7\xe0': u'\ub8c5',
'\xb7\xe1': u'\ub8cc',
'\xb7\xe2': u'\ub8d0',
'\xb7\xe3': u'\ub8d4',
'\xb7\xe4': u'\ub8dd',
'\xb7\xe5': u'\ub8df',
'\xb7\xe6': u'\ub8e1',
'\xb7\xe7': u'\ub8e8',
'\xb7\xe8': u'\ub8e9',
'\xb7\xe9': u'\ub8ec',
'\xb7\xea': u'\ub8f0',
'\xb7\xeb': u'\ub8f8',
'\xb7\xec': u'\ub8f9',
'\xb7\xed': u'\ub8fb',
'\xb7\xee': u'\ub8fd',
'\xb7\xef': u'\ub904',
'\xb7\xf0': u'\ub918',
'\xb7\xf1': u'\ub920',
'\xb7\xf2': u'\ub93c',
'\xb7\xf3': u'\ub93d',
'\xb7\xf4': u'\ub940',
'\xb7\xf5': u'\ub944',
'\xb7\xf6': u'\ub94c',
'\xb7\xf7': u'\ub94f',
'\xb7\xf8': u'\ub951',
'\xb7\xf9': u'\ub958',
'\xb7\xfa': u'\ub959',
'\xb7\xfb': u'\ub95c',
'\xb7\xfc': u'\ub960',
'\xb7\xfd': u'\ub968',
'\xb7\xfe': u'\ub969',
'\xb8\xa1': u'\ub96b',
'\xb8\xa2': u'\ub96d',
'\xb8\xa3': u'\ub974',
'\xb8\xa4': u'\ub975',
'\xb8\xa5': u'\ub978',
'\xb8\xa6': u'\ub97c',
'\xb8\xa7': u'\ub984',
'\xb8\xa8': u'\ub985',
'\xb8\xa9': u'\ub987',
'\xb8\xaa': u'\ub989',
'\xb8\xab': u'\ub98a',
'\xb8\xac': u'\ub98d',
'\xb8\xad': u'\ub98e',
'\xb8\xae': u'\ub9ac',
'\xb8\xaf': u'\ub9ad',
'\xb8\xb0': u'\ub9b0',
'\xb8\xb1': u'\ub9b4',
'\xb8\xb2': u'\ub9bc',
'\xb8\xb3': u'\ub9bd',
'\xb8\xb4': u'\ub9bf',
'\xb8\xb5': u'\ub9c1',
'\xb8\xb6': u'\ub9c8',
'\xb8\xb7': u'\ub9c9',
'\xb8\xb8': u'\ub9cc',
'\xb8\xb9': u'\ub9ce',
'\xb8\xba': u'\ub9cf',
'\xb8\xbb': u'\ub9d0',
'\xb8\xbc': u'\ub9d1',
'\xb8\xbd': u'\ub9d2',
'\xb8\xbe': u'\ub9d8',
'\xb8\xbf': u'\ub9d9',
'\xb8\xc0': u'\ub9db',
'\xb8\xc1': u'\ub9dd',
'\xb8\xc2': u'\ub9de',
'\xb8\xc3': u'\ub9e1',
'\xb8\xc4': u'\ub9e3',
'\xb8\xc5': u'\ub9e4',
'\xb8\xc6': u'\ub9e5',
'\xb8\xc7': u'\ub9e8',
'\xb8\xc8': u'\ub9ec',
'\xb8\xc9': u'\ub9f4',
'\xb8\xca': u'\ub9f5',
'\xb8\xcb': u'\ub9f7',
'\xb8\xcc': u'\ub9f8',
'\xb8\xcd': u'\ub9f9',
'\xb8\xce': u'\ub9fa',
'\xb8\xcf': u'\uba00',
'\xb8\xd0': u'\uba01',
'\xb8\xd1': u'\uba08',
'\xb8\xd2': u'\uba15',
'\xb8\xd3': u'\uba38',
'\xb8\xd4': u'\uba39',
'\xb8\xd5': u'\uba3c',
'\xb8\xd6': u'\uba40',
'\xb8\xd7': u'\uba42',
'\xb8\xd8': u'\uba48',
'\xb8\xd9': u'\uba49',
'\xb8\xda': u'\uba4b',
'\xb8\xdb': u'\uba4d',
'\xb8\xdc': u'\uba4e',
'\xb8\xdd': u'\uba53',
'\xb8\xde': u'\uba54',
'\xb8\xdf': u'\uba55',
'\xb8\xe0': u'\uba58',
'\xb8\xe1': u'\uba5c',
'\xb8\xe2': u'\uba64',
'\xb8\xe3': u'\uba65',
'\xb8\xe4': u'\uba67',
'\xb8\xe5': u'\uba68',
'\xb8\xe6': u'\uba69',
'\xb8\xe7': u'\uba70',
'\xb8\xe8': u'\uba71',
'\xb8\xe9': u'\uba74',
'\xb8\xea': u'\uba78',
'\xb8\xeb': u'\uba83',
'\xb8\xec': u'\uba84',
'\xb8\xed': u'\uba85',
'\xb8\xee': u'\uba87',
'\xb8\xef': u'\uba8c',
'\xb8\xf0': u'\ubaa8',
'\xb8\xf1': u'\ubaa9',
'\xb8\xf2': u'\ubaab',
'\xb8\xf3': u'\ubaac',
'\xb8\xf4': u'\ubab0',
'\xb8\xf5': u'\ubab2',
'\xb8\xf6': u'\ubab8',
'\xb8\xf7': u'\ubab9',
'\xb8\xf8': u'\ubabb',
'\xb8\xf9': u'\ubabd',
'\xb8\xfa': u'\ubac4',
'\xb8\xfb': u'\ubac8',
'\xb8\xfc': u'\ubad8',
'\xb8\xfd': u'\ubad9',
'\xb8\xfe': u'\ubafc',
'\xb9\xa1': u'\ubb00',
'\xb9\xa2': u'\ubb04',
'\xb9\xa3': u'\ubb0d',
'\xb9\xa4': u'\ubb0f',
'\xb9\xa5': u'\ubb11',
'\xb9\xa6': u'\ubb18',
'\xb9\xa7': u'\ubb1c',
'\xb9\xa8': u'\ubb20',
'\xb9\xa9': u'\ubb29',
'\xb9\xaa': u'\ubb2b',
'\xb9\xab': u'\ubb34',
'\xb9\xac': u'\ubb35',
'\xb9\xad': u'\ubb36',
'\xb9\xae': u'\ubb38',
'\xb9\xaf': u'\ubb3b',
'\xb9\xb0': u'\ubb3c',
'\xb9\xb1': u'\ubb3d',
'\xb9\xb2': u'\ubb3e',
'\xb9\xb3': u'\ubb44',
'\xb9\xb4': u'\ubb45',
'\xb9\xb5': u'\ubb47',
'\xb9\xb6': u'\ubb49',
'\xb9\xb7': u'\ubb4d',
'\xb9\xb8': u'\ubb4f',
'\xb9\xb9': u'\ubb50',
'\xb9\xba': u'\ubb54',
'\xb9\xbb': u'\ubb58',
'\xb9\xbc': u'\ubb61',
'\xb9\xbd': u'\ubb63',
'\xb9\xbe': u'\ubb6c',
'\xb9\xbf': u'\ubb88',
'\xb9\xc0': u'\ubb8c',
'\xb9\xc1': u'\ubb90',
'\xb9\xc2': u'\ubba4',
'\xb9\xc3': u'\ubba8',
'\xb9\xc4': u'\ubbac',
'\xb9\xc5': u'\ubbb4',
'\xb9\xc6': u'\ubbb7',
'\xb9\xc7': u'\ubbc0',
'\xb9\xc8': u'\ubbc4',
'\xb9\xc9': u'\ubbc8',
'\xb9\xca': u'\ubbd0',
'\xb9\xcb': u'\ubbd3',
'\xb9\xcc': u'\ubbf8',
'\xb9\xcd': u'\ubbf9',
'\xb9\xce': u'\ubbfc',
'\xb9\xcf': u'\ubbff',
'\xb9\xd0': u'\ubc00',
'\xb9\xd1': u'\ubc02',
'\xb9\xd2': u'\ubc08',
'\xb9\xd3': u'\ubc09',
'\xb9\xd4': u'\ubc0b',
'\xb9\xd5': u'\ubc0c',
'\xb9\xd6': u'\ubc0d',
'\xb9\xd7': u'\ubc0f',
'\xb9\xd8': u'\ubc11',
'\xb9\xd9': u'\ubc14',
'\xb9\xda': u'\ubc15',
'\xb9\xdb': u'\ubc16',
'\xb9\xdc': u'\ubc17',
'\xb9\xdd': u'\ubc18',
'\xb9\xde': u'\ubc1b',
'\xb9\xdf': u'\ubc1c',
'\xb9\xe0': u'\ubc1d',
'\xb9\xe1': u'\ubc1e',
'\xb9\xe2': u'\ubc1f',
'\xb9\xe3': u'\ubc24',
'\xb9\xe4': u'\ubc25',
'\xb9\xe5': u'\ubc27',
'\xb9\xe6': u'\ubc29',
'\xb9\xe7': u'\ubc2d',
'\xb9\xe8': u'\ubc30',
'\xb9\xe9': u'\ubc31',
'\xb9\xea': u'\ubc34',
'\xb9\xeb': u'\ubc38',
'\xb9\xec': u'\ubc40',
'\xb9\xed': u'\ubc41',
'\xb9\xee': u'\ubc43',
'\xb9\xef': u'\ubc44',
'\xb9\xf0': u'\ubc45',
'\xb9\xf1': u'\ubc49',
'\xb9\xf2': u'\ubc4c',
'\xb9\xf3': u'\ubc4d',
'\xb9\xf4': u'\ubc50',
'\xb9\xf5': u'\ubc5d',
'\xb9\xf6': u'\ubc84',
'\xb9\xf7': u'\ubc85',
'\xb9\xf8': u'\ubc88',
'\xb9\xf9': u'\ubc8b',
'\xb9\xfa': u'\ubc8c',
'\xb9\xfb': u'\ubc8e',
'\xb9\xfc': u'\ubc94',
'\xb9\xfd': u'\ubc95',
'\xb9\xfe': u'\ubc97',
'\xba\xa1': u'\ubc99',
'\xba\xa2': u'\ubc9a',
'\xba\xa3': u'\ubca0',
'\xba\xa4': u'\ubca1',
'\xba\xa5': u'\ubca4',
'\xba\xa6': u'\ubca7',
'\xba\xa7': u'\ubca8',
'\xba\xa8': u'\ubcb0',
'\xba\xa9': u'\ubcb1',
'\xba\xaa': u'\ubcb3',
'\xba\xab': u'\ubcb4',
'\xba\xac': u'\ubcb5',
'\xba\xad': u'\ubcbc',
'\xba\xae': u'\ubcbd',
'\xba\xaf': u'\ubcc0',
'\xba\xb0': u'\ubcc4',
'\xba\xb1': u'\ubccd',
'\xba\xb2': u'\ubccf',
'\xba\xb3': u'\ubcd0',
'\xba\xb4': u'\ubcd1',
'\xba\xb5': u'\ubcd5',
'\xba\xb6': u'\ubcd8',
'\xba\xb7': u'\ubcdc',
'\xba\xb8': u'\ubcf4',
'\xba\xb9': u'\ubcf5',
'\xba\xba': u'\ubcf6',
'\xba\xbb': u'\ubcf8',
'\xba\xbc': u'\ubcfc',
'\xba\xbd': u'\ubd04',
'\xba\xbe': u'\ubd05',
'\xba\xbf': u'\ubd07',
'\xba\xc0': u'\ubd09',
'\xba\xc1': u'\ubd10',
'\xba\xc2': u'\ubd14',
'\xba\xc3': u'\ubd24',
'\xba\xc4': u'\ubd2c',
'\xba\xc5': u'\ubd40',
'\xba\xc6': u'\ubd48',
'\xba\xc7': u'\ubd49',
'\xba\xc8': u'\ubd4c',
'\xba\xc9': u'\ubd50',
'\xba\xca': u'\ubd58',
'\xba\xcb': u'\ubd59',
'\xba\xcc': u'\ubd64',
'\xba\xcd': u'\ubd68',
'\xba\xce': u'\ubd80',
'\xba\xcf': u'\ubd81',
'\xba\xd0': u'\ubd84',
'\xba\xd1': u'\ubd87',
'\xba\xd2': u'\ubd88',
'\xba\xd3': u'\ubd89',
'\xba\xd4': u'\ubd8a',
'\xba\xd5': u'\ubd90',
'\xba\xd6': u'\ubd91',
'\xba\xd7': u'\ubd93',
'\xba\xd8': u'\ubd95',
'\xba\xd9': u'\ubd99',
'\xba\xda': u'\ubd9a',
'\xba\xdb': u'\ubd9c',
'\xba\xdc': u'\ubda4',
'\xba\xdd': u'\ubdb0',
'\xba\xde': u'\ubdb8',
'\xba\xdf': u'\ubdd4',
'\xba\xe0': u'\ubdd5',
'\xba\xe1': u'\ubdd8',
'\xba\xe2': u'\ubddc',
'\xba\xe3': u'\ubde9',
'\xba\xe4': u'\ubdf0',
'\xba\xe5': u'\ubdf4',
'\xba\xe6': u'\ubdf8',
'\xba\xe7': u'\ube00',
'\xba\xe8': u'\ube03',
'\xba\xe9': u'\ube05',
'\xba\xea': u'\ube0c',
'\xba\xeb': u'\ube0d',
'\xba\xec': u'\ube10',
'\xba\xed': u'\ube14',
'\xba\xee': u'\ube1c',
'\xba\xef': u'\ube1d',
'\xba\xf0': u'\ube1f',
'\xba\xf1': u'\ube44',
'\xba\xf2': u'\ube45',
'\xba\xf3': u'\ube48',
'\xba\xf4': u'\ube4c',
'\xba\xf5': u'\ube4e',
'\xba\xf6': u'\ube54',
'\xba\xf7': u'\ube55',
'\xba\xf8': u'\ube57',
'\xba\xf9': u'\ube59',
'\xba\xfa': u'\ube5a',
'\xba\xfb': u'\ube5b',
'\xba\xfc': u'\ube60',
'\xba\xfd': u'\ube61',
'\xba\xfe': u'\ube64',
'\xbb\xa1': u'\ube68',
'\xbb\xa2': u'\ube6a',
'\xbb\xa3': u'\ube70',
'\xbb\xa4': u'\ube71',
'\xbb\xa5': u'\ube73',
'\xbb\xa6': u'\ube74',
'\xbb\xa7': u'\ube75',
'\xbb\xa8': u'\ube7b',
'\xbb\xa9': u'\ube7c',
'\xbb\xaa': u'\ube7d',
'\xbb\xab': u'\ube80',
'\xbb\xac': u'\ube84',
'\xbb\xad': u'\ube8c',
'\xbb\xae': u'\ube8d',
'\xbb\xaf': u'\ube8f',
'\xbb\xb0': u'\ube90',
'\xbb\xb1': u'\ube91',
'\xbb\xb2': u'\ube98',
'\xbb\xb3': u'\ube99',
'\xbb\xb4': u'\ubea8',
'\xbb\xb5': u'\ubed0',
'\xbb\xb6': u'\ubed1',
'\xbb\xb7': u'\ubed4',
'\xbb\xb8': u'\ubed7',
'\xbb\xb9': u'\ubed8',
'\xbb\xba': u'\ubee0',
'\xbb\xbb': u'\ubee3',
'\xbb\xbc': u'\ubee4',
'\xbb\xbd': u'\ubee5',
'\xbb\xbe': u'\ubeec',
'\xbb\xbf': u'\ubf01',
'\xbb\xc0': u'\ubf08',
'\xbb\xc1': u'\ubf09',
'\xbb\xc2': u'\ubf18',
'\xbb\xc3': u'\ubf19',
'\xbb\xc4': u'\ubf1b',
'\xbb\xc5': u'\ubf1c',
'\xbb\xc6': u'\ubf1d',
'\xbb\xc7': u'\ubf40',
'\xbb\xc8': u'\ubf41',
'\xbb\xc9': u'\ubf44',
'\xbb\xca': u'\ubf48',
'\xbb\xcb': u'\ubf50',
'\xbb\xcc': u'\ubf51',
'\xbb\xcd': u'\ubf55',
'\xbb\xce': u'\ubf94',
'\xbb\xcf': u'\ubfb0',
'\xbb\xd0': u'\ubfc5',
'\xbb\xd1': u'\ubfcc',
'\xbb\xd2': u'\ubfcd',
'\xbb\xd3': u'\ubfd0',
'\xbb\xd4': u'\ubfd4',
'\xbb\xd5': u'\ubfdc',
'\xbb\xd6': u'\ubfdf',
'\xbb\xd7': u'\ubfe1',
'\xbb\xd8': u'\uc03c',
'\xbb\xd9': u'\uc051',
'\xbb\xda': u'\uc058',
'\xbb\xdb': u'\uc05c',
'\xbb\xdc': u'\uc060',
'\xbb\xdd': u'\uc068',
'\xbb\xde': u'\uc069',
'\xbb\xdf': u'\uc090',
'\xbb\xe0': u'\uc091',
'\xbb\xe1': u'\uc094',
'\xbb\xe2': u'\uc098',
'\xbb\xe3': u'\uc0a0',
'\xbb\xe4': u'\uc0a1',
'\xbb\xe5': u'\uc0a3',
'\xbb\xe6': u'\uc0a5',
'\xbb\xe7': u'\uc0ac',
'\xbb\xe8': u'\uc0ad',
'\xbb\xe9': u'\uc0af',
'\xbb\xea': u'\uc0b0',
'\xbb\xeb': u'\uc0b3',
'\xbb\xec': u'\uc0b4',
'\xbb\xed': u'\uc0b5',
'\xbb\xee': u'\uc0b6',
'\xbb\xef': u'\uc0bc',
'\xbb\xf0': u'\uc0bd',
'\xbb\xf1': u'\uc0bf',
'\xbb\xf2': u'\uc0c0',
'\xbb\xf3': u'\uc0c1',
'\xbb\xf4': u'\uc0c5',
'\xbb\xf5': u'\uc0c8',
'\xbb\xf6': u'\uc0c9',
'\xbb\xf7': u'\uc0cc',
'\xbb\xf8': u'\uc0d0',
'\xbb\xf9': u'\uc0d8',
'\xbb\xfa': u'\uc0d9',
'\xbb\xfb': u'\uc0db',
'\xbb\xfc': u'\uc0dc',
'\xbb\xfd': u'\uc0dd',
'\xbb\xfe': u'\uc0e4',
'\xbc\xa1': u'\uc0e5',
'\xbc\xa2': u'\uc0e8',
'\xbc\xa3': u'\uc0ec',
'\xbc\xa4': u'\uc0f4',
'\xbc\xa5': u'\uc0f5',
'\xbc\xa6': u'\uc0f7',
'\xbc\xa7': u'\uc0f9',
'\xbc\xa8': u'\uc100',
'\xbc\xa9': u'\uc104',
'\xbc\xaa': u'\uc108',
'\xbc\xab': u'\uc110',
'\xbc\xac': u'\uc115',
'\xbc\xad': u'\uc11c',
'\xbc\xae': u'\uc11d',
'\xbc\xaf': u'\uc11e',
'\xbc\xb0': u'\uc11f',
'\xbc\xb1': u'\uc120',
'\xbc\xb2': u'\uc123',
'\xbc\xb3': u'\uc124',
'\xbc\xb4': u'\uc126',
'\xbc\xb5': u'\uc127',
'\xbc\xb6': u'\uc12c',
'\xbc\xb7': u'\uc12d',
'\xbc\xb8': u'\uc12f',
'\xbc\xb9': u'\uc130',
'\xbc\xba': u'\uc131',
'\xbc\xbb': u'\uc136',
'\xbc\xbc': u'\uc138',
'\xbc\xbd': u'\uc139',
'\xbc\xbe': u'\uc13c',
'\xbc\xbf': u'\uc140',
'\xbc\xc0': u'\uc148',
'\xbc\xc1': u'\uc149',
'\xbc\xc2': u'\uc14b',
'\xbc\xc3': u'\uc14c',
'\xbc\xc4': u'\uc14d',
'\xbc\xc5': u'\uc154',
'\xbc\xc6': u'\uc155',
'\xbc\xc7': u'\uc158',
'\xbc\xc8': u'\uc15c',
'\xbc\xc9': u'\uc164',
'\xbc\xca': u'\uc165',
'\xbc\xcb': u'\uc167',
'\xbc\xcc': u'\uc168',
'\xbc\xcd': u'\uc169',
'\xbc\xce': u'\uc170',
'\xbc\xcf': u'\uc174',
'\xbc\xd0': u'\uc178',
'\xbc\xd1': u'\uc185',
'\xbc\xd2': u'\uc18c',
'\xbc\xd3': u'\uc18d',
'\xbc\xd4': u'\uc18e',
'\xbc\xd5': u'\uc190',
'\xbc\xd6': u'\uc194',
'\xbc\xd7': u'\uc196',
'\xbc\xd8': u'\uc19c',
'\xbc\xd9': u'\uc19d',
'\xbc\xda': u'\uc19f',
'\xbc\xdb': u'\uc1a1',
'\xbc\xdc': u'\uc1a5',
'\xbc\xdd': u'\uc1a8',
'\xbc\xde': u'\uc1a9',
'\xbc\xdf': u'\uc1ac',
'\xbc\xe0': u'\uc1b0',
'\xbc\xe1': u'\uc1bd',
'\xbc\xe2': u'\uc1c4',
'\xbc\xe3': u'\uc1c8',
'\xbc\xe4': u'\uc1cc',
'\xbc\xe5': u'\uc1d4',
'\xbc\xe6': u'\uc1d7',
'\xbc\xe7': u'\uc1d8',
'\xbc\xe8': u'\uc1e0',
'\xbc\xe9': u'\uc1e4',
'\xbc\xea': u'\uc1e8',
'\xbc\xeb': u'\uc1f0',
'\xbc\xec': u'\uc1f1',
'\xbc\xed': u'\uc1f3',
'\xbc\xee': u'\uc1fc',
'\xbc\xef': u'\uc1fd',
'\xbc\xf0': u'\uc200',
'\xbc\xf1': u'\uc204',
'\xbc\xf2': u'\uc20c',
'\xbc\xf3': u'\uc20d',
'\xbc\xf4': u'\uc20f',
'\xbc\xf5': u'\uc211',
'\xbc\xf6': u'\uc218',
'\xbc\xf7': u'\uc219',
'\xbc\xf8': u'\uc21c',
'\xbc\xf9': u'\uc21f',
'\xbc\xfa': u'\uc220',
'\xbc\xfb': u'\uc228',
'\xbc\xfc': u'\uc229',
'\xbc\xfd': u'\uc22b',
'\xbc\xfe': u'\uc22d',
'\xbd\xa1': u'\uc22f',
'\xbd\xa2': u'\uc231',
'\xbd\xa3': u'\uc232',
'\xbd\xa4': u'\uc234',
'\xbd\xa5': u'\uc248',
'\xbd\xa6': u'\uc250',
'\xbd\xa7': u'\uc251',
'\xbd\xa8': u'\uc254',
'\xbd\xa9': u'\uc258',
'\xbd\xaa': u'\uc260',
'\xbd\xab': u'\uc265',
'\xbd\xac': u'\uc26c',
'\xbd\xad': u'\uc26d',
'\xbd\xae': u'\uc270',
'\xbd\xaf': u'\uc274',
'\xbd\xb0': u'\uc27c',
'\xbd\xb1': u'\uc27d',
'\xbd\xb2': u'\uc27f',
'\xbd\xb3': u'\uc281',
'\xbd\xb4': u'\uc288',
'\xbd\xb5': u'\uc289',
'\xbd\xb6': u'\uc290',
'\xbd\xb7': u'\uc298',
'\xbd\xb8': u'\uc29b',
'\xbd\xb9': u'\uc29d',
'\xbd\xba': u'\uc2a4',
'\xbd\xbb': u'\uc2a5',
'\xbd\xbc': u'\uc2a8',
'\xbd\xbd': u'\uc2ac',
'\xbd\xbe': u'\uc2ad',
'\xbd\xbf': u'\uc2b4',
'\xbd\xc0': u'\uc2b5',
'\xbd\xc1': u'\uc2b7',
'\xbd\xc2': u'\uc2b9',
'\xbd\xc3': u'\uc2dc',
'\xbd\xc4': u'\uc2dd',
'\xbd\xc5': u'\uc2e0',
'\xbd\xc6': u'\uc2e3',
'\xbd\xc7': u'\uc2e4',
'\xbd\xc8': u'\uc2eb',
'\xbd\xc9': u'\uc2ec',
'\xbd\xca': u'\uc2ed',
'\xbd\xcb': u'\uc2ef',
'\xbd\xcc': u'\uc2f1',
'\xbd\xcd': u'\uc2f6',
'\xbd\xce': u'\uc2f8',
'\xbd\xcf': u'\uc2f9',
'\xbd\xd0': u'\uc2fb',
'\xbd\xd1': u'\uc2fc',
'\xbd\xd2': u'\uc300',
'\xbd\xd3': u'\uc308',
'\xbd\xd4': u'\uc309',
'\xbd\xd5': u'\uc30c',
'\xbd\xd6': u'\uc30d',
'\xbd\xd7': u'\uc313',
'\xbd\xd8': u'\uc314',
'\xbd\xd9': u'\uc315',
'\xbd\xda': u'\uc318',
'\xbd\xdb': u'\uc31c',
'\xbd\xdc': u'\uc324',
'\xbd\xdd': u'\uc325',
'\xbd\xde': u'\uc328',
'\xbd\xdf': u'\uc329',
'\xbd\xe0': u'\uc345',
'\xbd\xe1': u'\uc368',
'\xbd\xe2': u'\uc369',
'\xbd\xe3': u'\uc36c',
'\xbd\xe4': u'\uc370',
'\xbd\xe5': u'\uc372',
'\xbd\xe6': u'\uc378',
'\xbd\xe7': u'\uc379',
'\xbd\xe8': u'\uc37c',
'\xbd\xe9': u'\uc37d',
'\xbd\xea': u'\uc384',
'\xbd\xeb': u'\uc388',
'\xbd\xec': u'\uc38c',
'\xbd\xed': u'\uc3c0',
'\xbd\xee': u'\uc3d8',
'\xbd\xef': u'\uc3d9',
'\xbd\xf0': u'\uc3dc',
'\xbd\xf1': u'\uc3df',
'\xbd\xf2': u'\uc3e0',
'\xbd\xf3': u'\uc3e2',
'\xbd\xf4': u'\uc3e8',
'\xbd\xf5': u'\uc3e9',
'\xbd\xf6': u'\uc3ed',
'\xbd\xf7': u'\uc3f4',
'\xbd\xf8': u'\uc3f5',
'\xbd\xf9': u'\uc3f8',
'\xbd\xfa': u'\uc408',
'\xbd\xfb': u'\uc410',
'\xbd\xfc': u'\uc424',
'\xbd\xfd': u'\uc42c',
'\xbd\xfe': u'\uc430',
'\xbe\xa1': u'\uc434',
'\xbe\xa2': u'\uc43c',
'\xbe\xa3': u'\uc43d',
'\xbe\xa4': u'\uc448',
'\xbe\xa5': u'\uc464',
'\xbe\xa6': u'\uc465',
'\xbe\xa7': u'\uc468',
'\xbe\xa8': u'\uc46c',
'\xbe\xa9': u'\uc474',
'\xbe\xaa': u'\uc475',
'\xbe\xab': u'\uc479',
'\xbe\xac': u'\uc480',
'\xbe\xad': u'\uc494',
'\xbe\xae': u'\uc49c',
'\xbe\xaf': u'\uc4b8',
'\xbe\xb0': u'\uc4bc',
'\xbe\xb1': u'\uc4e9',
'\xbe\xb2': u'\uc4f0',
'\xbe\xb3': u'\uc4f1',
'\xbe\xb4': u'\uc4f4',
'\xbe\xb5': u'\uc4f8',
'\xbe\xb6': u'\uc4fa',
'\xbe\xb7': u'\uc4ff',
'\xbe\xb8': u'\uc500',
'\xbe\xb9': u'\uc501',
'\xbe\xba': u'\uc50c',
'\xbe\xbb': u'\uc510',
'\xbe\xbc': u'\uc514',
'\xbe\xbd': u'\uc51c',
'\xbe\xbe': u'\uc528',
'\xbe\xbf': u'\uc529',
'\xbe\xc0': u'\uc52c',
'\xbe\xc1': u'\uc530',
'\xbe\xc2': u'\uc538',
'\xbe\xc3': u'\uc539',
'\xbe\xc4': u'\uc53b',
'\xbe\xc5': u'\uc53d',
'\xbe\xc6': u'\uc544',
'\xbe\xc7': u'\uc545',
'\xbe\xc8': u'\uc548',
'\xbe\xc9': u'\uc549',
'\xbe\xca': u'\uc54a',
'\xbe\xcb': u'\uc54c',
'\xbe\xcc': u'\uc54d',
'\xbe\xcd': u'\uc54e',
'\xbe\xce': u'\uc553',
'\xbe\xcf': u'\uc554',
'\xbe\xd0': u'\uc555',
'\xbe\xd1': u'\uc557',
'\xbe\xd2': u'\uc558',
'\xbe\xd3': u'\uc559',
'\xbe\xd4': u'\uc55d',
'\xbe\xd5': u'\uc55e',
'\xbe\xd6': u'\uc560',
'\xbe\xd7': u'\uc561',
'\xbe\xd8': u'\uc564',
'\xbe\xd9': u'\uc568',
'\xbe\xda': u'\uc570',
'\xbe\xdb': u'\uc571',
'\xbe\xdc': u'\uc573',
'\xbe\xdd': u'\uc574',
'\xbe\xde': u'\uc575',
'\xbe\xdf': u'\uc57c',
'\xbe\xe0': u'\uc57d',
'\xbe\xe1': u'\uc580',
'\xbe\xe2': u'\uc584',
'\xbe\xe3': u'\uc587',
'\xbe\xe4': u'\uc58c',
'\xbe\xe5': u'\uc58d',
'\xbe\xe6': u'\uc58f',
'\xbe\xe7': u'\uc591',
'\xbe\xe8': u'\uc595',
'\xbe\xe9': u'\uc597',
'\xbe\xea': u'\uc598',
'\xbe\xeb': u'\uc59c',
'\xbe\xec': u'\uc5a0',
'\xbe\xed': u'\uc5a9',
'\xbe\xee': u'\uc5b4',
'\xbe\xef': u'\uc5b5',
'\xbe\xf0': u'\uc5b8',
'\xbe\xf1': u'\uc5b9',
'\xbe\xf2': u'\uc5bb',
'\xbe\xf3': u'\uc5bc',
'\xbe\xf4': u'\uc5bd',
'\xbe\xf5': u'\uc5be',
'\xbe\xf6': u'\uc5c4',
'\xbe\xf7': u'\uc5c5',
'\xbe\xf8': u'\uc5c6',
'\xbe\xf9': u'\uc5c7',
'\xbe\xfa': u'\uc5c8',
'\xbe\xfb': u'\uc5c9',
'\xbe\xfc': u'\uc5ca',
'\xbe\xfd': u'\uc5cc',
'\xbe\xfe': u'\uc5ce',
'\xbf\xa1': u'\uc5d0',
'\xbf\xa2': u'\uc5d1',
'\xbf\xa3': u'\uc5d4',
'\xbf\xa4': u'\uc5d8',
'\xbf\xa5': u'\uc5e0',
'\xbf\xa6': u'\uc5e1',
'\xbf\xa7': u'\uc5e3',
'\xbf\xa8': u'\uc5e5',
'\xbf\xa9': u'\uc5ec',
'\xbf\xaa': u'\uc5ed',
'\xbf\xab': u'\uc5ee',
'\xbf\xac': u'\uc5f0',
'\xbf\xad': u'\uc5f4',
'\xbf\xae': u'\uc5f6',
'\xbf\xaf': u'\uc5f7',
'\xbf\xb0': u'\uc5fc',
'\xbf\xb1': u'\uc5fd',
'\xbf\xb2': u'\uc5fe',
'\xbf\xb3': u'\uc5ff',
'\xbf\xb4': u'\uc600',
'\xbf\xb5': u'\uc601',
'\xbf\xb6': u'\uc605',
'\xbf\xb7': u'\uc606',
'\xbf\xb8': u'\uc607',
'\xbf\xb9': u'\uc608',
'\xbf\xba': u'\uc60c',
'\xbf\xbb': u'\uc610',
'\xbf\xbc': u'\uc618',
'\xbf\xbd': u'\uc619',
'\xbf\xbe': u'\uc61b',
'\xbf\xbf': u'\uc61c',
'\xbf\xc0': u'\uc624',
'\xbf\xc1': u'\uc625',
'\xbf\xc2': u'\uc628',
'\xbf\xc3': u'\uc62c',
'\xbf\xc4': u'\uc62d',
'\xbf\xc5': u'\uc62e',
'\xbf\xc6': u'\uc630',
'\xbf\xc7': u'\uc633',
'\xbf\xc8': u'\uc634',
'\xbf\xc9': u'\uc635',
'\xbf\xca': u'\uc637',
'\xbf\xcb': u'\uc639',
'\xbf\xcc': u'\uc63b',
'\xbf\xcd': u'\uc640',
'\xbf\xce': u'\uc641',
'\xbf\xcf': u'\uc644',
'\xbf\xd0': u'\uc648',
'\xbf\xd1': u'\uc650',
'\xbf\xd2': u'\uc651',
'\xbf\xd3': u'\uc653',
'\xbf\xd4': u'\uc654',
'\xbf\xd5': u'\uc655',
'\xbf\xd6': u'\uc65c',
'\xbf\xd7': u'\uc65d',
'\xbf\xd8': u'\uc660',
'\xbf\xd9': u'\uc66c',
'\xbf\xda': u'\uc66f',
'\xbf\xdb': u'\uc671',
'\xbf\xdc': u'\uc678',
'\xbf\xdd': u'\uc679',
'\xbf\xde': u'\uc67c',
'\xbf\xdf': u'\uc680',
'\xbf\xe0': u'\uc688',
'\xbf\xe1': u'\uc689',
'\xbf\xe2': u'\uc68b',
'\xbf\xe3': u'\uc68d',
'\xbf\xe4': u'\uc694',
'\xbf\xe5': u'\uc695',
'\xbf\xe6': u'\uc698',
'\xbf\xe7': u'\uc69c',
'\xbf\xe8': u'\uc6a4',
'\xbf\xe9': u'\uc6a5',
'\xbf\xea': u'\uc6a7',
'\xbf\xeb': u'\uc6a9',
'\xbf\xec': u'\uc6b0',
'\xbf\xed': u'\uc6b1',
'\xbf\xee': u'\uc6b4',
'\xbf\xef': u'\uc6b8',
'\xbf\xf0': u'\uc6b9',
'\xbf\xf1': u'\uc6ba',
'\xbf\xf2': u'\uc6c0',
'\xbf\xf3': u'\uc6c1',
'\xbf\xf4': u'\uc6c3',
'\xbf\xf5': u'\uc6c5',
'\xbf\xf6': u'\uc6cc',
'\xbf\xf7': u'\uc6cd',
'\xbf\xf8': u'\uc6d0',
'\xbf\xf9': u'\uc6d4',
'\xbf\xfa': u'\uc6dc',
'\xbf\xfb': u'\uc6dd',
'\xbf\xfc': u'\uc6e0',
'\xbf\xfd': u'\uc6e1',
'\xbf\xfe': u'\uc6e8',
'\xc0\xa1': u'\uc6e9',
'\xc0\xa2': u'\uc6ec',
'\xc0\xa3': u'\uc6f0',
'\xc0\xa4': u'\uc6f8',
'\xc0\xa5': u'\uc6f9',
'\xc0\xa6': u'\uc6fd',
'\xc0\xa7': u'\uc704',
'\xc0\xa8': u'\uc705',
'\xc0\xa9': u'\uc708',
'\xc0\xaa': u'\uc70c',
'\xc0\xab': u'\uc714',
'\xc0\xac': u'\uc715',
'\xc0\xad': u'\uc717',
'\xc0\xae': u'\uc719',
'\xc0\xaf': u'\uc720',
'\xc0\xb0': u'\uc721',
'\xc0\xb1': u'\uc724',
'\xc0\xb2': u'\uc728',
'\xc0\xb3': u'\uc730',
'\xc0\xb4': u'\uc731',
'\xc0\xb5': u'\uc733',
'\xc0\xb6': u'\uc735',
'\xc0\xb7': u'\uc737',
'\xc0\xb8': u'\uc73c',
'\xc0\xb9': u'\uc73d',
'\xc0\xba': u'\uc740',
'\xc0\xbb': u'\uc744',
'\xc0\xbc': u'\uc74a',
'\xc0\xbd': u'\uc74c',
'\xc0\xbe': u'\uc74d',
'\xc0\xbf': u'\uc74f',
'\xc0\xc0': u'\uc751',
'\xc0\xc1': u'\uc752',
'\xc0\xc2': u'\uc753',
'\xc0\xc3': u'\uc754',
'\xc0\xc4': u'\uc755',
'\xc0\xc5': u'\uc756',
'\xc0\xc6': u'\uc757',
'\xc0\xc7': u'\uc758',
'\xc0\xc8': u'\uc75c',
'\xc0\xc9': u'\uc760',
'\xc0\xca': u'\uc768',
'\xc0\xcb': u'\uc76b',
'\xc0\xcc': u'\uc774',
'\xc0\xcd': u'\uc775',
'\xc0\xce': u'\uc778',
'\xc0\xcf': u'\uc77c',
'\xc0\xd0': u'\uc77d',
'\xc0\xd1': u'\uc77e',
'\xc0\xd2': u'\uc783',
'\xc0\xd3': u'\uc784',
'\xc0\xd4': u'\uc785',
'\xc0\xd5': u'\uc787',
'\xc0\xd6': u'\uc788',
'\xc0\xd7': u'\uc789',
'\xc0\xd8': u'\uc78a',
'\xc0\xd9': u'\uc78e',
'\xc0\xda': u'\uc790',
'\xc0\xdb': u'\uc791',
'\xc0\xdc': u'\uc794',
'\xc0\xdd': u'\uc796',
'\xc0\xde': u'\uc797',
'\xc0\xdf': u'\uc798',
'\xc0\xe0': u'\uc79a',
'\xc0\xe1': u'\uc7a0',
'\xc0\xe2': u'\uc7a1',
'\xc0\xe3': u'\uc7a3',
'\xc0\xe4': u'\uc7a4',
'\xc0\xe5': u'\uc7a5',
'\xc0\xe6': u'\uc7a6',
'\xc0\xe7': u'\uc7ac',
'\xc0\xe8': u'\uc7ad',
'\xc0\xe9': u'\uc7b0',
'\xc0\xea': u'\uc7b4',
'\xc0\xeb': u'\uc7bc',
'\xc0\xec': u'\uc7bd',
'\xc0\xed': u'\uc7bf',
'\xc0\xee': u'\uc7c0',
'\xc0\xef': u'\uc7c1',
'\xc0\xf0': u'\uc7c8',
'\xc0\xf1': u'\uc7c9',
'\xc0\xf2': u'\uc7cc',
'\xc0\xf3': u'\uc7ce',
'\xc0\xf4': u'\uc7d0',
'\xc0\xf5': u'\uc7d8',
'\xc0\xf6': u'\uc7dd',
'\xc0\xf7': u'\uc7e4',
'\xc0\xf8': u'\uc7e8',
'\xc0\xf9': u'\uc7ec',
'\xc0\xfa': u'\uc800',
'\xc0\xfb': u'\uc801',
'\xc0\xfc': u'\uc804',
'\xc0\xfd': u'\uc808',
'\xc0\xfe': u'\uc80a',
'\xc1\xa1': u'\uc810',
'\xc1\xa2': u'\uc811',
'\xc1\xa3': u'\uc813',
'\xc1\xa4': u'\uc815',
'\xc1\xa5': u'\uc816',
'\xc1\xa6': u'\uc81c',
'\xc1\xa7': u'\uc81d',
'\xc1\xa8': u'\uc820',
'\xc1\xa9': u'\uc824',
'\xc1\xaa': u'\uc82c',
'\xc1\xab': u'\uc82d',
'\xc1\xac': u'\uc82f',
'\xc1\xad': u'\uc831',
'\xc1\xae': u'\uc838',
'\xc1\xaf': u'\uc83c',
'\xc1\xb0': u'\uc840',
'\xc1\xb1': u'\uc848',
'\xc1\xb2': u'\uc849',
'\xc1\xb3': u'\uc84c',
'\xc1\xb4': u'\uc84d',
'\xc1\xb5': u'\uc854',
'\xc1\xb6': u'\uc870',
'\xc1\xb7': u'\uc871',
'\xc1\xb8': u'\uc874',
'\xc1\xb9': u'\uc878',
'\xc1\xba': u'\uc87a',
'\xc1\xbb': u'\uc880',
'\xc1\xbc': u'\uc881',
'\xc1\xbd': u'\uc883',
'\xc1\xbe': u'\uc885',
'\xc1\xbf': u'\uc886',
'\xc1\xc0': u'\uc887',
'\xc1\xc1': u'\uc88b',
'\xc1\xc2': u'\uc88c',
'\xc1\xc3': u'\uc88d',
'\xc1\xc4': u'\uc894',
'\xc1\xc5': u'\uc89d',
'\xc1\xc6': u'\uc89f',
'\xc1\xc7': u'\uc8a1',
'\xc1\xc8': u'\uc8a8',
'\xc1\xc9': u'\uc8bc',
'\xc1\xca': u'\uc8bd',
'\xc1\xcb': u'\uc8c4',
'\xc1\xcc': u'\uc8c8',
'\xc1\xcd': u'\uc8cc',
'\xc1\xce': u'\uc8d4',
'\xc1\xcf': u'\uc8d5',
'\xc1\xd0': u'\uc8d7',
'\xc1\xd1': u'\uc8d9',
'\xc1\xd2': u'\uc8e0',
'\xc1\xd3': u'\uc8e1',
'\xc1\xd4': u'\uc8e4',
'\xc1\xd5': u'\uc8f5',
'\xc1\xd6': u'\uc8fc',
'\xc1\xd7': u'\uc8fd',
'\xc1\xd8': u'\uc900',
'\xc1\xd9': u'\uc904',
'\xc1\xda': u'\uc905',
'\xc1\xdb': u'\uc906',
'\xc1\xdc': u'\uc90c',
'\xc1\xdd': u'\uc90d',
'\xc1\xde': u'\uc90f',
'\xc1\xdf': u'\uc911',
'\xc1\xe0': u'\uc918',
'\xc1\xe1': u'\uc92c',
'\xc1\xe2': u'\uc934',
'\xc1\xe3': u'\uc950',
'\xc1\xe4': u'\uc951',
'\xc1\xe5': u'\uc954',
'\xc1\xe6': u'\uc958',
'\xc1\xe7': u'\uc960',
'\xc1\xe8': u'\uc961',
'\xc1\xe9': u'\uc963',
'\xc1\xea': u'\uc96c',
'\xc1\xeb': u'\uc970',
'\xc1\xec': u'\uc974',
'\xc1\xed': u'\uc97c',
'\xc1\xee': u'\uc988',
'\xc1\xef': u'\uc989',
'\xc1\xf0': u'\uc98c',
'\xc1\xf1': u'\uc990',
'\xc1\xf2': u'\uc998',
'\xc1\xf3': u'\uc999',
'\xc1\xf4': u'\uc99b',
'\xc1\xf5': u'\uc99d',
'\xc1\xf6': u'\uc9c0',
'\xc1\xf7': u'\uc9c1',
'\xc1\xf8': u'\uc9c4',
'\xc1\xf9': u'\uc9c7',
'\xc1\xfa': u'\uc9c8',
'\xc1\xfb': u'\uc9ca',
'\xc1\xfc': u'\uc9d0',
'\xc1\xfd': u'\uc9d1',
'\xc1\xfe': u'\uc9d3',
'\xc2\xa1': u'\uc9d5',
'\xc2\xa2': u'\uc9d6',
'\xc2\xa3': u'\uc9d9',
'\xc2\xa4': u'\uc9da',
'\xc2\xa5': u'\uc9dc',
'\xc2\xa6': u'\uc9dd',
'\xc2\xa7': u'\uc9e0',
'\xc2\xa8': u'\uc9e2',
'\xc2\xa9': u'\uc9e4',
'\xc2\xaa': u'\uc9e7',
'\xc2\xab': u'\uc9ec',
'\xc2\xac': u'\uc9ed',
'\xc2\xad': u'\uc9ef',
'\xc2\xae': u'\uc9f0',
'\xc2\xaf': u'\uc9f1',
'\xc2\xb0': u'\uc9f8',
'\xc2\xb1': u'\uc9f9',
'\xc2\xb2': u'\uc9fc',
'\xc2\xb3': u'\uca00',
'\xc2\xb4': u'\uca08',
'\xc2\xb5': u'\uca09',
'\xc2\xb6': u'\uca0b',
'\xc2\xb7': u'\uca0c',
'\xc2\xb8': u'\uca0d',
'\xc2\xb9': u'\uca14',
'\xc2\xba': u'\uca18',
'\xc2\xbb': u'\uca29',
'\xc2\xbc': u'\uca4c',
'\xc2\xbd': u'\uca4d',
'\xc2\xbe': u'\uca50',
'\xc2\xbf': u'\uca54',
'\xc2\xc0': u'\uca5c',
'\xc2\xc1': u'\uca5d',
'\xc2\xc2': u'\uca5f',
'\xc2\xc3': u'\uca60',
'\xc2\xc4': u'\uca61',
'\xc2\xc5': u'\uca68',
'\xc2\xc6': u'\uca7d',
'\xc2\xc7': u'\uca84',
'\xc2\xc8': u'\uca98',
'\xc2\xc9': u'\ucabc',
'\xc2\xca': u'\ucabd',
'\xc2\xcb': u'\ucac0',
'\xc2\xcc': u'\ucac4',
'\xc2\xcd': u'\ucacc',
'\xc2\xce': u'\ucacd',
'\xc2\xcf': u'\ucacf',
'\xc2\xd0': u'\ucad1',
'\xc2\xd1': u'\ucad3',
'\xc2\xd2': u'\ucad8',
'\xc2\xd3': u'\ucad9',
'\xc2\xd4': u'\ucae0',
'\xc2\xd5': u'\ucaec',
'\xc2\xd6': u'\ucaf4',
'\xc2\xd7': u'\ucb08',
'\xc2\xd8': u'\ucb10',
'\xc2\xd9': u'\ucb14',
'\xc2\xda': u'\ucb18',
'\xc2\xdb': u'\ucb20',
'\xc2\xdc': u'\ucb21',
'\xc2\xdd': u'\ucb41',
'\xc2\xde': u'\ucb48',
'\xc2\xdf': u'\ucb49',
'\xc2\xe0': u'\ucb4c',
'\xc2\xe1': u'\ucb50',
'\xc2\xe2': u'\ucb58',
'\xc2\xe3': u'\ucb59',
'\xc2\xe4': u'\ucb5d',
'\xc2\xe5': u'\ucb64',
'\xc2\xe6': u'\ucb78',
'\xc2\xe7': u'\ucb79',
'\xc2\xe8': u'\ucb9c',
'\xc2\xe9': u'\ucbb8',
'\xc2\xea': u'\ucbd4',
'\xc2\xeb': u'\ucbe4',
'\xc2\xec': u'\ucbe7',
'\xc2\xed': u'\ucbe9',
'\xc2\xee': u'\ucc0c',
'\xc2\xef': u'\ucc0d',
'\xc2\xf0': u'\ucc10',
'\xc2\xf1': u'\ucc14',
'\xc2\xf2': u'\ucc1c',
'\xc2\xf3': u'\ucc1d',
'\xc2\xf4': u'\ucc21',
'\xc2\xf5': u'\ucc22',
'\xc2\xf6': u'\ucc27',
'\xc2\xf7': u'\ucc28',
'\xc2\xf8': u'\ucc29',
'\xc2\xf9': u'\ucc2c',
'\xc2\xfa': u'\ucc2e',
'\xc2\xfb': u'\ucc30',
'\xc2\xfc': u'\ucc38',
'\xc2\xfd': u'\ucc39',
'\xc2\xfe': u'\ucc3b',
'\xc3\xa1': u'\ucc3c',
'\xc3\xa2': u'\ucc3d',
'\xc3\xa3': u'\ucc3e',
'\xc3\xa4': u'\ucc44',
'\xc3\xa5': u'\ucc45',
'\xc3\xa6': u'\ucc48',
'\xc3\xa7': u'\ucc4c',
'\xc3\xa8': u'\ucc54',
'\xc3\xa9': u'\ucc55',
'\xc3\xaa': u'\ucc57',
'\xc3\xab': u'\ucc58',
'\xc3\xac': u'\ucc59',
'\xc3\xad': u'\ucc60',
'\xc3\xae': u'\ucc64',
'\xc3\xaf': u'\ucc66',
'\xc3\xb0': u'\ucc68',
'\xc3\xb1': u'\ucc70',
'\xc3\xb2': u'\ucc75',
'\xc3\xb3': u'\ucc98',
'\xc3\xb4': u'\ucc99',
'\xc3\xb5': u'\ucc9c',
'\xc3\xb6': u'\ucca0',
'\xc3\xb7': u'\ucca8',
'\xc3\xb8': u'\ucca9',
'\xc3\xb9': u'\uccab',
'\xc3\xba': u'\uccac',
'\xc3\xbb': u'\uccad',
'\xc3\xbc': u'\uccb4',
'\xc3\xbd': u'\uccb5',
'\xc3\xbe': u'\uccb8',
'\xc3\xbf': u'\uccbc',
'\xc3\xc0': u'\uccc4',
'\xc3\xc1': u'\uccc5',
'\xc3\xc2': u'\uccc7',
'\xc3\xc3': u'\uccc9',
'\xc3\xc4': u'\uccd0',
'\xc3\xc5': u'\uccd4',
'\xc3\xc6': u'\ucce4',
'\xc3\xc7': u'\uccec',
'\xc3\xc8': u'\uccf0',
'\xc3\xc9': u'\ucd01',
'\xc3\xca': u'\ucd08',
'\xc3\xcb': u'\ucd09',
'\xc3\xcc': u'\ucd0c',
'\xc3\xcd': u'\ucd10',
'\xc3\xce': u'\ucd18',
'\xc3\xcf': u'\ucd19',
'\xc3\xd0': u'\ucd1b',
'\xc3\xd1': u'\ucd1d',
'\xc3\xd2': u'\ucd24',
'\xc3\xd3': u'\ucd28',
'\xc3\xd4': u'\ucd2c',
'\xc3\xd5': u'\ucd39',
'\xc3\xd6': u'\ucd5c',
'\xc3\xd7': u'\ucd60',
'\xc3\xd8': u'\ucd64',
'\xc3\xd9': u'\ucd6c',
'\xc3\xda': u'\ucd6d',
'\xc3\xdb': u'\ucd6f',
'\xc3\xdc': u'\ucd71',
'\xc3\xdd': u'\ucd78',
'\xc3\xde': u'\ucd88',
'\xc3\xdf': u'\ucd94',
'\xc3\xe0': u'\ucd95',
'\xc3\xe1': u'\ucd98',
'\xc3\xe2': u'\ucd9c',
'\xc3\xe3': u'\ucda4',
'\xc3\xe4': u'\ucda5',
'\xc3\xe5': u'\ucda7',
'\xc3\xe6': u'\ucda9',
'\xc3\xe7': u'\ucdb0',
'\xc3\xe8': u'\ucdc4',
'\xc3\xe9': u'\ucdcc',
'\xc3\xea': u'\ucdd0',
'\xc3\xeb': u'\ucde8',
'\xc3\xec': u'\ucdec',
'\xc3\xed': u'\ucdf0',
'\xc3\xee': u'\ucdf8',
'\xc3\xef': u'\ucdf9',
'\xc3\xf0': u'\ucdfb',
'\xc3\xf1': u'\ucdfd',
'\xc3\xf2': u'\uce04',
'\xc3\xf3': u'\uce08',
'\xc3\xf4': u'\uce0c',
'\xc3\xf5': u'\uce14',
'\xc3\xf6': u'\uce19',
'\xc3\xf7': u'\uce20',
'\xc3\xf8': u'\uce21',
'\xc3\xf9': u'\uce24',
'\xc3\xfa': u'\uce28',
'\xc3\xfb': u'\uce30',
'\xc3\xfc': u'\uce31',
'\xc3\xfd': u'\uce33',
'\xc3\xfe': u'\uce35',
'\xc4\xa1': u'\uce58',
'\xc4\xa2': u'\uce59',
'\xc4\xa3': u'\uce5c',
'\xc4\xa4': u'\uce5f',
'\xc4\xa5': u'\uce60',
'\xc4\xa6': u'\uce61',
'\xc4\xa7': u'\uce68',
'\xc4\xa8': u'\uce69',
'\xc4\xa9': u'\uce6b',
'\xc4\xaa': u'\uce6d',
'\xc4\xab': u'\uce74',
'\xc4\xac': u'\uce75',
'\xc4\xad': u'\uce78',
'\xc4\xae': u'\uce7c',
'\xc4\xaf': u'\uce84',
'\xc4\xb0': u'\uce85',
'\xc4\xb1': u'\uce87',
'\xc4\xb2': u'\uce89',
'\xc4\xb3': u'\uce90',
'\xc4\xb4': u'\uce91',
'\xc4\xb5': u'\uce94',
'\xc4\xb6': u'\uce98',
'\xc4\xb7': u'\ucea0',
'\xc4\xb8': u'\ucea1',
'\xc4\xb9': u'\ucea3',
'\xc4\xba': u'\ucea4',
'\xc4\xbb': u'\ucea5',
'\xc4\xbc': u'\uceac',
'\xc4\xbd': u'\ucead',
'\xc4\xbe': u'\ucec1',
'\xc4\xbf': u'\ucee4',
'\xc4\xc0': u'\ucee5',
'\xc4\xc1': u'\ucee8',
'\xc4\xc2': u'\uceeb',
'\xc4\xc3': u'\uceec',
'\xc4\xc4': u'\ucef4',
'\xc4\xc5': u'\ucef5',
'\xc4\xc6': u'\ucef7',
'\xc4\xc7': u'\ucef8',
'\xc4\xc8': u'\ucef9',
'\xc4\xc9': u'\ucf00',
'\xc4\xca': u'\ucf01',
'\xc4\xcb': u'\ucf04',
'\xc4\xcc': u'\ucf08',
'\xc4\xcd': u'\ucf10',
'\xc4\xce': u'\ucf11',
'\xc4\xcf': u'\ucf13',
'\xc4\xd0': u'\ucf15',
'\xc4\xd1': u'\ucf1c',
'\xc4\xd2': u'\ucf20',
'\xc4\xd3': u'\ucf24',
'\xc4\xd4': u'\ucf2c',
'\xc4\xd5': u'\ucf2d',
'\xc4\xd6': u'\ucf2f',
'\xc4\xd7': u'\ucf30',
'\xc4\xd8': u'\ucf31',
'\xc4\xd9': u'\ucf38',
'\xc4\xda': u'\ucf54',
'\xc4\xdb': u'\ucf55',
'\xc4\xdc': u'\ucf58',
'\xc4\xdd': u'\ucf5c',
'\xc4\xde': u'\ucf64',
'\xc4\xdf': u'\ucf65',
'\xc4\xe0': u'\ucf67',
'\xc4\xe1': u'\ucf69',
'\xc4\xe2': u'\ucf70',
'\xc4\xe3': u'\ucf71',
'\xc4\xe4': u'\ucf74',
'\xc4\xe5': u'\ucf78',
'\xc4\xe6': u'\ucf80',
'\xc4\xe7': u'\ucf85',
'\xc4\xe8': u'\ucf8c',
'\xc4\xe9': u'\ucfa1',
'\xc4\xea': u'\ucfa8',
'\xc4\xeb': u'\ucfb0',
'\xc4\xec': u'\ucfc4',
'\xc4\xed': u'\ucfe0',
'\xc4\xee': u'\ucfe1',
'\xc4\xef': u'\ucfe4',
'\xc4\xf0': u'\ucfe8',
'\xc4\xf1': u'\ucff0',
'\xc4\xf2': u'\ucff1',
'\xc4\xf3': u'\ucff3',
'\xc4\xf4': u'\ucff5',
'\xc4\xf5': u'\ucffc',
'\xc4\xf6': u'\ud000',
'\xc4\xf7': u'\ud004',
'\xc4\xf8': u'\ud011',
'\xc4\xf9': u'\ud018',
'\xc4\xfa': u'\ud02d',
'\xc4\xfb': u'\ud034',
'\xc4\xfc': u'\ud035',
'\xc4\xfd': u'\ud038',
'\xc4\xfe': u'\ud03c',
'\xc5\xa1': u'\ud044',
'\xc5\xa2': u'\ud045',
'\xc5\xa3': u'\ud047',
'\xc5\xa4': u'\ud049',
'\xc5\xa5': u'\ud050',
'\xc5\xa6': u'\ud054',
'\xc5\xa7': u'\ud058',
'\xc5\xa8': u'\ud060',
'\xc5\xa9': u'\ud06c',
'\xc5\xaa': u'\ud06d',
'\xc5\xab': u'\ud070',
'\xc5\xac': u'\ud074',
'\xc5\xad': u'\ud07c',
'\xc5\xae': u'\ud07d',
'\xc5\xaf': u'\ud081',
'\xc5\xb0': u'\ud0a4',
'\xc5\xb1': u'\ud0a5',
'\xc5\xb2': u'\ud0a8',
'\xc5\xb3': u'\ud0ac',
'\xc5\xb4': u'\ud0b4',
'\xc5\xb5': u'\ud0b5',
'\xc5\xb6': u'\ud0b7',
'\xc5\xb7': u'\ud0b9',
'\xc5\xb8': u'\ud0c0',
'\xc5\xb9': u'\ud0c1',
'\xc5\xba': u'\ud0c4',
'\xc5\xbb': u'\ud0c8',
'\xc5\xbc': u'\ud0c9',
'\xc5\xbd': u'\ud0d0',
'\xc5\xbe': u'\ud0d1',
'\xc5\xbf': u'\ud0d3',
'\xc5\xc0': u'\ud0d4',
'\xc5\xc1': u'\ud0d5',
'\xc5\xc2': u'\ud0dc',
'\xc5\xc3': u'\ud0dd',
'\xc5\xc4': u'\ud0e0',
'\xc5\xc5': u'\ud0e4',
'\xc5\xc6': u'\ud0ec',
'\xc5\xc7': u'\ud0ed',
'\xc5\xc8': u'\ud0ef',
'\xc5\xc9': u'\ud0f0',
'\xc5\xca': u'\ud0f1',
'\xc5\xcb': u'\ud0f8',
'\xc5\xcc': u'\ud10d',
'\xc5\xcd': u'\ud130',
'\xc5\xce': u'\ud131',
'\xc5\xcf': u'\ud134',
'\xc5\xd0': u'\ud138',
'\xc5\xd1': u'\ud13a',
'\xc5\xd2': u'\ud140',
'\xc5\xd3': u'\ud141',
'\xc5\xd4': u'\ud143',
'\xc5\xd5': u'\ud144',
'\xc5\xd6': u'\ud145',
'\xc5\xd7': u'\ud14c',
'\xc5\xd8': u'\ud14d',
'\xc5\xd9': u'\ud150',
'\xc5\xda': u'\ud154',
'\xc5\xdb': u'\ud15c',
'\xc5\xdc': u'\ud15d',
'\xc5\xdd': u'\ud15f',
'\xc5\xde': u'\ud161',
'\xc5\xdf': u'\ud168',
'\xc5\xe0': u'\ud16c',
'\xc5\xe1': u'\ud17c',
'\xc5\xe2': u'\ud184',
'\xc5\xe3': u'\ud188',
'\xc5\xe4': u'\ud1a0',
'\xc5\xe5': u'\ud1a1',
'\xc5\xe6': u'\ud1a4',
'\xc5\xe7': u'\ud1a8',
'\xc5\xe8': u'\ud1b0',
'\xc5\xe9': u'\ud1b1',
'\xc5\xea': u'\ud1b3',
'\xc5\xeb': u'\ud1b5',
'\xc5\xec': u'\ud1ba',
'\xc5\xed': u'\ud1bc',
'\xc5\xee': u'\ud1c0',
'\xc5\xef': u'\ud1d8',
'\xc5\xf0': u'\ud1f4',
'\xc5\xf1': u'\ud1f8',
'\xc5\xf2': u'\ud207',
'\xc5\xf3': u'\ud209',
'\xc5\xf4': u'\ud210',
'\xc5\xf5': u'\ud22c',
'\xc5\xf6': u'\ud22d',
'\xc5\xf7': u'\ud230',
'\xc5\xf8': u'\ud234',
'\xc5\xf9': u'\ud23c',
'\xc5\xfa': u'\ud23d',
'\xc5\xfb': u'\ud23f',
'\xc5\xfc': u'\ud241',
'\xc5\xfd': u'\ud248',
'\xc5\xfe': u'\ud25c',
'\xc6\xa1': u'\ud264',
'\xc6\xa2': u'\ud280',
'\xc6\xa3': u'\ud281',
'\xc6\xa4': u'\ud284',
'\xc6\xa5': u'\ud288',
'\xc6\xa6': u'\ud290',
'\xc6\xa7': u'\ud291',
'\xc6\xa8': u'\ud295',
'\xc6\xa9': u'\ud29c',
'\xc6\xaa': u'\ud2a0',
'\xc6\xab': u'\ud2a4',
'\xc6\xac': u'\ud2ac',
'\xc6\xad': u'\ud2b1',
'\xc6\xae': u'\ud2b8',
'\xc6\xaf': u'\ud2b9',
'\xc6\xb0': u'\ud2bc',
'\xc6\xb1': u'\ud2bf',
'\xc6\xb2': u'\ud2c0',
'\xc6\xb3': u'\ud2c2',
'\xc6\xb4': u'\ud2c8',
'\xc6\xb5': u'\ud2c9',
'\xc6\xb6': u'\ud2cb',
'\xc6\xb7': u'\ud2d4',
'\xc6\xb8': u'\ud2d8',
'\xc6\xb9': u'\ud2dc',
'\xc6\xba': u'\ud2e4',
'\xc6\xbb': u'\ud2e5',
'\xc6\xbc': u'\ud2f0',
'\xc6\xbd': u'\ud2f1',
'\xc6\xbe': u'\ud2f4',
'\xc6\xbf': u'\ud2f8',
'\xc6\xc0': u'\ud300',
'\xc6\xc1': u'\ud301',
'\xc6\xc2': u'\ud303',
'\xc6\xc3': u'\ud305',
'\xc6\xc4': u'\ud30c',
'\xc6\xc5': u'\ud30d',
'\xc6\xc6': u'\ud30e',
'\xc6\xc7': u'\ud310',
'\xc6\xc8': u'\ud314',
'\xc6\xc9': u'\ud316',
'\xc6\xca': u'\ud31c',
'\xc6\xcb': u'\ud31d',
'\xc6\xcc': u'\ud31f',
'\xc6\xcd': u'\ud320',
'\xc6\xce': u'\ud321',
'\xc6\xcf': u'\ud325',
'\xc6\xd0': u'\ud328',
'\xc6\xd1': u'\ud329',
'\xc6\xd2': u'\ud32c',
'\xc6\xd3': u'\ud330',
'\xc6\xd4': u'\ud338',
'\xc6\xd5': u'\ud339',
'\xc6\xd6': u'\ud33b',
'\xc6\xd7': u'\ud33c',
'\xc6\xd8': u'\ud33d',
'\xc6\xd9': u'\ud344',
'\xc6\xda': u'\ud345',
'\xc6\xdb': u'\ud37c',
'\xc6\xdc': u'\ud37d',
'\xc6\xdd': u'\ud380',
'\xc6\xde': u'\ud384',
'\xc6\xdf': u'\ud38c',
'\xc6\xe0': u'\ud38d',
'\xc6\xe1': u'\ud38f',
'\xc6\xe2': u'\ud390',
'\xc6\xe3': u'\ud391',
'\xc6\xe4': u'\ud398',
'\xc6\xe5': u'\ud399',
'\xc6\xe6': u'\ud39c',
'\xc6\xe7': u'\ud3a0',
'\xc6\xe8': u'\ud3a8',
'\xc6\xe9': u'\ud3a9',
'\xc6\xea': u'\ud3ab',
'\xc6\xeb': u'\ud3ad',
'\xc6\xec': u'\ud3b4',
'\xc6\xed': u'\ud3b8',
'\xc6\xee': u'\ud3bc',
'\xc6\xef': u'\ud3c4',
'\xc6\xf0': u'\ud3c5',
'\xc6\xf1': u'\ud3c8',
'\xc6\xf2': u'\ud3c9',
'\xc6\xf3': u'\ud3d0',
'\xc6\xf4': u'\ud3d8',
'\xc6\xf5': u'\ud3e1',
'\xc6\xf6': u'\ud3e3',
'\xc6\xf7': u'\ud3ec',
'\xc6\xf8': u'\ud3ed',
'\xc6\xf9': u'\ud3f0',
'\xc6\xfa': u'\ud3f4',
'\xc6\xfb': u'\ud3fc',
'\xc6\xfc': u'\ud3fd',
'\xc6\xfd': u'\ud3ff',
'\xc6\xfe': u'\ud401',
'\xc7\xa1': u'\ud408',
'\xc7\xa2': u'\ud41d',
'\xc7\xa3': u'\ud440',
'\xc7\xa4': u'\ud444',
'\xc7\xa5': u'\ud45c',
'\xc7\xa6': u'\ud460',
'\xc7\xa7': u'\ud464',
'\xc7\xa8': u'\ud46d',
'\xc7\xa9': u'\ud46f',
'\xc7\xaa': u'\ud478',
'\xc7\xab': u'\ud479',
'\xc7\xac': u'\ud47c',
'\xc7\xad': u'\ud47f',
'\xc7\xae': u'\ud480',
'\xc7\xaf': u'\ud482',
'\xc7\xb0': u'\ud488',
'\xc7\xb1': u'\ud489',
'\xc7\xb2': u'\ud48b',
'\xc7\xb3': u'\ud48d',
'\xc7\xb4': u'\ud494',
'\xc7\xb5': u'\ud4a9',
'\xc7\xb6': u'\ud4cc',
'\xc7\xb7': u'\ud4d0',
'\xc7\xb8': u'\ud4d4',
'\xc7\xb9': u'\ud4dc',
'\xc7\xba': u'\ud4df',
'\xc7\xbb': u'\ud4e8',
'\xc7\xbc': u'\ud4ec',
'\xc7\xbd': u'\ud4f0',
'\xc7\xbe': u'\ud4f8',
'\xc7\xbf': u'\ud4fb',
'\xc7\xc0': u'\ud4fd',
'\xc7\xc1': u'\ud504',
'\xc7\xc2': u'\ud508',
'\xc7\xc3': u'\ud50c',
'\xc7\xc4': u'\ud514',
'\xc7\xc5': u'\ud515',
'\xc7\xc6': u'\ud517',
'\xc7\xc7': u'\ud53c',
'\xc7\xc8': u'\ud53d',
'\xc7\xc9': u'\ud540',
'\xc7\xca': u'\ud544',
'\xc7\xcb': u'\ud54c',
'\xc7\xcc': u'\ud54d',
'\xc7\xcd': u'\ud54f',
'\xc7\xce': u'\ud551',
'\xc7\xcf': u'\ud558',
'\xc7\xd0': u'\ud559',
'\xc7\xd1': u'\ud55c',
'\xc7\xd2': u'\ud560',
'\xc7\xd3': u'\ud565',
'\xc7\xd4': u'\ud568',
'\xc7\xd5': u'\ud569',
'\xc7\xd6': u'\ud56b',
'\xc7\xd7': u'\ud56d',
'\xc7\xd8': u'\ud574',
'\xc7\xd9': u'\ud575',
'\xc7\xda': u'\ud578',
'\xc7\xdb': u'\ud57c',
'\xc7\xdc': u'\ud584',
'\xc7\xdd': u'\ud585',
'\xc7\xde': u'\ud587',
'\xc7\xdf': u'\ud588',
'\xc7\xe0': u'\ud589',
'\xc7\xe1': u'\ud590',
'\xc7\xe2': u'\ud5a5',
'\xc7\xe3': u'\ud5c8',
'\xc7\xe4': u'\ud5c9',
'\xc7\xe5': u'\ud5cc',
'\xc7\xe6': u'\ud5d0',
'\xc7\xe7': u'\ud5d2',
'\xc7\xe8': u'\ud5d8',
'\xc7\xe9': u'\ud5d9',
'\xc7\xea': u'\ud5db',
'\xc7\xeb': u'\ud5dd',
'\xc7\xec': u'\ud5e4',
'\xc7\xed': u'\ud5e5',
'\xc7\xee': u'\ud5e8',
'\xc7\xef': u'\ud5ec',
'\xc7\xf0': u'\ud5f4',
'\xc7\xf1': u'\ud5f5',
'\xc7\xf2': u'\ud5f7',
'\xc7\xf3': u'\ud5f9',
'\xc7\xf4': u'\ud600',
'\xc7\xf5': u'\ud601',
'\xc7\xf6': u'\ud604',
'\xc7\xf7': u'\ud608',
'\xc7\xf8': u'\ud610',
'\xc7\xf9': u'\ud611',
'\xc7\xfa': u'\ud613',
'\xc7\xfb': u'\ud614',
'\xc7\xfc': u'\ud615',
'\xc7\xfd': u'\ud61c',
'\xc7\xfe': u'\ud620',
'\xc8\xa1': u'\ud624',
'\xc8\xa2': u'\ud62d',
'\xc8\xa3': u'\ud638',
'\xc8\xa4': u'\ud639',
'\xc8\xa5': u'\ud63c',
'\xc8\xa6': u'\ud640',
'\xc8\xa7': u'\ud645',
'\xc8\xa8': u'\ud648',
'\xc8\xa9': u'\ud649',
'\xc8\xaa': u'\ud64b',
'\xc8\xab': u'\ud64d',
'\xc8\xac': u'\ud651',
'\xc8\xad': u'\ud654',
'\xc8\xae': u'\ud655',
'\xc8\xaf': u'\ud658',
'\xc8\xb0': u'\ud65c',
'\xc8\xb1': u'\ud667',
'\xc8\xb2': u'\ud669',
'\xc8\xb3': u'\ud670',
'\xc8\xb4': u'\ud671',
'\xc8\xb5': u'\ud674',
'\xc8\xb6': u'\ud683',
'\xc8\xb7': u'\ud685',
'\xc8\xb8': u'\ud68c',
'\xc8\xb9': u'\ud68d',
'\xc8\xba': u'\ud690',
'\xc8\xbb': u'\ud694',
'\xc8\xbc': u'\ud69d',
'\xc8\xbd': u'\ud69f',
'\xc8\xbe': u'\ud6a1',
'\xc8\xbf': u'\ud6a8',
'\xc8\xc0': u'\ud6ac',
'\xc8\xc1': u'\ud6b0',
'\xc8\xc2': u'\ud6b9',
'\xc8\xc3': u'\ud6bb',
'\xc8\xc4': u'\ud6c4',
'\xc8\xc5': u'\ud6c5',
'\xc8\xc6': u'\ud6c8',
'\xc8\xc7': u'\ud6cc',
'\xc8\xc8': u'\ud6d1',
'\xc8\xc9': u'\ud6d4',
'\xc8\xca': u'\ud6d7',
'\xc8\xcb': u'\ud6d9',
'\xc8\xcc': u'\ud6e0',
'\xc8\xcd': u'\ud6e4',
'\xc8\xce': u'\ud6e8',
'\xc8\xcf': u'\ud6f0',
'\xc8\xd0': u'\ud6f5',
'\xc8\xd1': u'\ud6fc',
'\xc8\xd2': u'\ud6fd',
'\xc8\xd3': u'\ud700',
'\xc8\xd4': u'\ud704',
'\xc8\xd5': u'\ud711',
'\xc8\xd6': u'\ud718',
'\xc8\xd7': u'\ud719',
'\xc8\xd8': u'\ud71c',
'\xc8\xd9': u'\ud720',
'\xc8\xda': u'\ud728',
'\xc8\xdb': u'\ud729',
'\xc8\xdc': u'\ud72b',
'\xc8\xdd': u'\ud72d',
'\xc8\xde': u'\ud734',
'\xc8\xdf': u'\ud735',
'\xc8\xe0': u'\ud738',
'\xc8\xe1': u'\ud73c',
'\xc8\xe2': u'\ud744',
'\xc8\xe3': u'\ud747',
'\xc8\xe4': u'\ud749',
'\xc8\xe5': u'\ud750',
'\xc8\xe6': u'\ud751',
'\xc8\xe7': u'\ud754',
'\xc8\xe8': u'\ud756',
'\xc8\xe9': u'\ud757',
'\xc8\xea': u'\ud758',
'\xc8\xeb': u'\ud759',
'\xc8\xec': u'\ud760',
'\xc8\xed': u'\ud761',
'\xc8\xee': u'\ud763',
'\xc8\xef': u'\ud765',
'\xc8\xf0': u'\ud769',
'\xc8\xf1': u'\ud76c',
'\xc8\xf2': u'\ud770',
'\xc8\xf3': u'\ud774',
'\xc8\xf4': u'\ud77c',
'\xc8\xf5': u'\ud77d',
'\xc8\xf6': u'\ud781',
'\xc8\xf7': u'\ud788',
'\xc8\xf8': u'\ud789',
'\xc8\xf9': u'\ud78c',
'\xc8\xfa': u'\ud790',
'\xc8\xfb': u'\ud798',
'\xc8\xfc': u'\ud799',
'\xc8\xfd': u'\ud79b',
'\xc8\xfe': u'\ud79d',
}

encoding_map = {}
for k, v in decoding_map.items():
    encoding_map[v] = k
